@@ -2,7 +2,7 @@
  *
  * $Id: index.cpp,v 1.30 1999/03/06 22:15:39 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -36,15 +36,12 @@
 #include "htags.h"
 #include "parserintf.h"
 #include "marshal.h"
-
-#if defined(_MSC_VER) || defined(__BORLANDC__)
-#define popen _popen
-#define pclose _pclose
-#endif
+#include "debug.h"
 
 #define START_MARKER 0x4445465B // DEF[
 #define END_MARKER   0x4445465D // DEF]
 
+//-----------------------------------------------------------------------------------------
 
 class DefinitionImpl
 {
@@ -61,17 +58,19 @@ class DefinitionImpl
     QList<ListItemInfo> *xrefListItems; 
     GroupList *partOfGroups;            
 
-    DocInfo   *details; // not exported
-    BriefInfo *brief;   // not exported
-    BodyInfo  *body;    // not exported
+    DocInfo   *details;    // not exported
+    DocInfo   *inbodyDocs; // not exported
+    BriefInfo *brief;      // not exported
+    BodyInfo  *body;       // not exported
     QCString   docSignatures;
 
     QCString localName;      // local (unqualified) name of the definition
-                               // in the future m_name should become m_localName
+                             // in the future m_name should become m_localName
     QCString qualifiedName;
     QCString ref;   // reference to external documentation
 
     bool hidden;
+    bool isArtificial;
 
     Definition *outerScope;  // not owner
 
@@ -84,7 +83,7 @@ class DefinitionImpl
 DefinitionImpl::DefinitionImpl() 
   : sectionDict(0), sourceRefByDict(0), sourceRefsDict(0), 
     xrefListItems(0), partOfGroups(0),
-    details(0), brief(0), body(0), 
+    details(0), inbodyDocs(0), brief(0), body(0), 
     outerScope(0)
 {
 }
@@ -99,6 +98,7 @@ DefinitionImpl::~DefinitionImpl()
   delete brief;
   delete details;
   delete body;
+  delete inbodyDocs;
 }
 
 void DefinitionImpl::init(const char *df,int dl,
@@ -123,16 +123,18 @@ void DefinitionImpl::init(const char *df,int dl,
   }
   //printf("m_localName=%s\n",m_localName.data());
 
-  brief = 0;
-  details = 0;
-  body = 0;
-  sourceRefByDict=0;
-  sourceRefsDict=0;
-  sectionDict=0, 
-  outerScope=Doxygen::globalScope;
-  partOfGroups=0;
-  xrefListItems=0;
-  hidden = FALSE;
+  brief           = 0;
+  details         = 0;
+  body            = 0;
+  inbodyDocs      = 0;
+  sourceRefByDict = 0;
+  sourceRefsDict  = 0;
+  sectionDict     = 0, 
+  outerScope      = Doxygen::globalScope;
+  partOfGroups    = 0;
+  xrefListItems   = 0;
+  hidden          = FALSE;
+  isArtificial    = FALSE;
 }
 
 //-----------------------------------------------------------------------------------------
@@ -283,7 +285,10 @@ Definition::Definition(const char *df,int dl,
   if (isSymbol) addToMap(name,this);
   _setBriefDescription(b,df,dl);
   _setDocumentation(d,df,dl,TRUE,FALSE);
-  if (matchExcludedSymbols(name)) m_impl->hidden = TRUE;
+  if (matchExcludedSymbols(name)) 
+  {
+    m_impl->hidden = TRUE;
+  }
 }
 
 Definition::~Definition()
@@ -299,6 +304,12 @@ Definition::~Definition()
   }
 }
 
+void Definition::setName(const char *name)
+{
+  if (name==0) return;
+  m_name = name;
+}
+
 void Definition::addSectionsToDefinition(QList<SectionInfo> *anchorList)
 {
   if (!anchorList) return;
@@ -350,11 +361,14 @@ void Definition::writeDocAnchorsToTagFile()
   }
 }
 
-bool Definition::_docsAlreadyAdded(const QString &doc)
+bool Definition::_docsAlreadyAdded(const QCString &doc)
 {
   uchar md5_sig[16];
   QCString sigStr(33);
-  MD5Buffer((const unsigned char *)doc.data(),doc.length(),md5_sig);
+  // to avoid mismatches due to differences in indenting, we first remove
+  // double whitespaces...
+  QCString docStr = doc.simplifyWhiteSpace();
+  MD5Buffer((const unsigned char *)docStr.data(),docStr.length(),md5_sig);
   MD5SigToString(md5_sig,sigStr.data(),33);
   if (m_impl->docSignatures.find(sigStr)==-1) // new docs, add signature to prevent re-adding it
   {
@@ -466,24 +480,63 @@ void Definition::setBriefDescription(const char *b,const char *briefFile,int bri
   _setBriefDescription(b,briefFile,briefLine);
 }
 
+void Definition::_setInbodyDocumentation(const char *doc,const char *inbodyFile,int inbodyLine)
+{
+  if (m_impl->inbodyDocs==0)
+  {
+    m_impl->inbodyDocs = new DocInfo;
+  }
+  if (m_impl->inbodyDocs->doc.isEmpty()) // fresh inbody docs
+  {
+    m_impl->inbodyDocs->doc  = doc;
+    m_impl->inbodyDocs->file = inbodyFile;
+    m_impl->inbodyDocs->line = inbodyLine;
+  }
+  else // another inbody documentation fragment, append this to the end
+  {
+    m_impl->inbodyDocs->doc += QCString("\n\n")+doc;
+  }
+}
+
+void Definition::setInbodyDocumentation(const char *d,const char *inbodyFile,int inbodyLine)
+{
+  if (d==0) return;
+  makeResident();
+  _setInbodyDocumentation(d,inbodyFile,inbodyLine);
+}
+
 /*! Reads a fragment of code from file \a fileName starting at 
  * line \a startLine and ending at line \a endLine (inclusive). The fragment is
  * stored in \a result. If FALSE is returned the code fragment could not be
  * found.
  *
- * The file is scanned for a opening bracket ('{') from \a startLine onward.
+ * The file is scanned for a opening bracket ('{') from \a startLine onward
  * The line actually containing the bracket is returned via startLine.
  * The file is scanned for a closing bracket ('}') from \a endLine backward.
  * The line actually containing the bracket is returned via endLine.
+ * Note that for VHDL code the bracket search is not done.
  */
 static bool readCodeFragment(const char *fileName,
                       int &startLine,int &endLine,QCString &result)
 {
+  static bool vhdlOpt           = Config_getBool("OPTIMIZE_OUTPUT_VHDL");
+  static bool filterSourceFiles = Config_getBool("FILTER_SOURCE_FILES");
   //printf("readCodeFragment(%s,%d,%d)\n",fileName,startLine,endLine);
   if (fileName==0 || fileName[0]==0) return FALSE; // not a valid file name
-  QCString cmd=getFileFilter(fileName)+" \""+fileName+"\"";
-  FILE *f = Config_getBool("FILTER_SOURCE_FILES") ? popen(cmd,"r") : fopen(fileName,"r");
-  bool found=FALSE;
+  QCString filter = getFileFilter(fileName);
+  FILE *f=0;
+  bool usePipe = !filter.isEmpty() && filterSourceFiles;
+  if (!usePipe) // no filter given or wanted
+  {
+    f = fopen(fileName,"r");
+  }
+  else // use filter
+  {
+    QCString cmd=filter+" \""+fileName+"\"";
+    Debug::print(Debug::ExtCmd,0,"Executing popen(`%s`)\n",cmd.data());
+    f = portable_popen(cmd,"r");
+  }
+  bool found=vhdlOpt;  // for VHDL no bracket search is possible
   if (f)
   {
     int c=0;
@@ -578,7 +631,14 @@ static bool readCodeFragment(const char *fileName,
         endLine=lineNr-1;
       }
     }
-    if (Config_getBool("FILTER_SOURCE_FILES")) pclose(f); else fclose(f);
+    if (usePipe) 
+    {
+      portable_pclose(f); 
+    }
+    else 
+    {
+      fclose(f);
+    }
   }
   result = transcodeCharacterStringToUTF8(result);
   return found;
@@ -587,10 +647,12 @@ static bool readCodeFragment(const char *fileName,
 /*! Write a reference to the source code defining this definition */
 void Definition::writeSourceDef(OutputList &ol,const char *)
 {
+  static bool sourceBrowser = Config_getBool("SOURCE_BROWSER");
+  static bool latexSourceCode = Config_getBool("LATEX_SOURCE_CODE");
   makeResident();
   ol.pushGeneratorState();
   //printf("Definition::writeSourceRef %d %p\n",bodyLine,bodyDef);
-  if (Config_getBool("SOURCE_BROWSER") && 
+  if (sourceBrowser && 
       m_impl->body && m_impl->body->startLine!=-1 && m_impl->body->fileDef)
   {
     QCString refText = theTranslator->trDefinedAtLineInSourceFile();
@@ -606,29 +668,49 @@ void Definition::writeSourceDef(OutputList &ol,const char *)
       {
         // write text left from linePos marker
         ol.parseText(refText.left(lineMarkerPos)); 
-        ol.disableAllBut(OutputGenerator::Html); 
-        // write line link (HTML only)
+        ol.pushGeneratorState();
+        ol.disable(OutputGenerator::RTF); 
+        ol.disable(OutputGenerator::Man); 
+        if (!latexSourceCode)
+        {
+          ol.disable(OutputGenerator::Latex);
+        }
+        // write line link (HTML, LaTeX optionally)
         ol.writeObjectLink(0,m_impl->body->fileDef->getSourceFileBase(),
             anchorStr,lineStr);
         ol.enableAll();
         ol.disable(OutputGenerator::Html);
-        // write normal text (Latex/Man only)
+        if (latexSourceCode) 
+        {
+          ol.disable(OutputGenerator::Latex);
+        }
+        // write normal text (Man/RTF, Latex optionally)
         ol.docify(lineStr);
-        ol.enableAll();
+        ol.popGeneratorState();
         
         // write text between markers
         ol.parseText(refText.mid(lineMarkerPos+2,
               fileMarkerPos-lineMarkerPos-2));
 
-        ol.disableAllBut(OutputGenerator::Html); 
-        // write file link (HTML only)
+        ol.pushGeneratorState();
+        ol.disable(OutputGenerator::RTF); 
+        ol.disable(OutputGenerator::Man); 
+        if (!latexSourceCode)
+        {
+          ol.disable(OutputGenerator::Latex);
+        }
+        // write line link (HTML, LaTeX optionally)
         ol.writeObjectLink(0,m_impl->body->fileDef->getSourceFileBase(),
             0,m_impl->body->fileDef->name());
         ol.enableAll();
         ol.disable(OutputGenerator::Html);
-        // write normal text (Latex/Man only)
+        if (latexSourceCode) 
+        {
+          ol.disable(OutputGenerator::Latex);
+        }
+        // write normal text (Man/RTF, Latex optionally)
         ol.docify(m_impl->body->fileDef->name());
-        ol.enableAll();
+        ol.popGeneratorState();
         
         // write text right from file marker
         ol.parseText(refText.right(
@@ -638,29 +720,50 @@ void Definition::writeSourceDef(OutputList &ol,const char *)
       {
         // write text left from file marker
         ol.parseText(refText.left(fileMarkerPos)); 
-        ol.disableAllBut(OutputGenerator::Html); 
+        ol.pushGeneratorState();
+        ol.disable(OutputGenerator::RTF); 
+        ol.disable(OutputGenerator::Man); 
+        if (!latexSourceCode)
+        {
+          ol.disable(OutputGenerator::Latex);
+        }
         // write file link (HTML only)
         ol.writeObjectLink(0,m_impl->body->fileDef->getSourceFileBase(),
             0,m_impl->body->fileDef->name());
         ol.enableAll();
         ol.disable(OutputGenerator::Html);
+        if (latexSourceCode) 
+        {
+          ol.disable(OutputGenerator::Latex);
+        }
         // write normal text (Latex/Man only)
         ol.docify(m_impl->body->fileDef->name());
-        ol.enableAll();
+        ol.popGeneratorState();
         
         // write text between markers
         ol.parseText(refText.mid(fileMarkerPos+2,
               lineMarkerPos-fileMarkerPos-2)); 
 
+        ol.pushGeneratorState();
+        ol.disable(OutputGenerator::RTF); 
+        ol.disable(OutputGenerator::Man); 
+        if (!latexSourceCode)
+        {
+          ol.disable(OutputGenerator::Latex);
+        }
         ol.disableAllBut(OutputGenerator::Html); 
         // write line link (HTML only)
         ol.writeObjectLink(0,m_impl->body->fileDef->getSourceFileBase(),
             anchorStr,lineStr);
         ol.enableAll();
         ol.disable(OutputGenerator::Html);
+        if (latexSourceCode) 
+        {
+          ol.disable(OutputGenerator::Latex);
+        }
         // write normal text (Latex/Man only)
         ol.docify(lineStr);
-        ol.enableAll();
+        ol.popGeneratorState();
 
         // write text right from linePos marker
         ol.parseText(refText.right(
@@ -709,6 +812,8 @@ void Definition::writeInlineCode(OutputList &ol,const char *scopeName)
           actualStart,actualEnd,codeFragment)
        )
     {
+      //printf("Adding code fragement '%s' ext='%s'\n",
+      //    codeFragment.data(),m_impl->defFileExt.data());
       ParserInterface *pIntf = Doxygen::parserManager->getParser(m_impl->defFileExt);
       pIntf->resetCodeParserState();
       //printf("Read:\n`%s'\n\n",codeFragment.data());
@@ -739,8 +844,9 @@ void Definition::writeInlineCode(OutputList &ol,const char *scopeName)
 void Definition::_writeSourceRefList(OutputList &ol,const char *scopeName,
     const QCString &text,MemberSDict *members,bool /*funcOnly*/)
 {
-  ol.pushGeneratorState();
-  if (Config_getBool("SOURCE_BROWSER") && members)
+static bool latexSourceCode = Config_getBool("LATEX_SOURCE_CODE"); 
+ ol.pushGeneratorState();
+  if (/*Config_getBool("SOURCE_BROWSER") &&*/ members)
   {
     ol.startParagraph();
     ol.parseText(text);
@@ -785,7 +891,14 @@ void Definition::_writeSourceRefList(OutputList &ol,const char *scopeName,
           //printf("md->getBodyDef()=%p global=%p\n",md->getBodyDef(),Doxygen::globalScope); 
           // for HTML write a real link
           ol.pushGeneratorState();
-          ol.disableAllBut(OutputGenerator::Html);
+          //ol.disableAllBut(OutputGenerator::Html);
+           
+         ol.disable(OutputGenerator::RTF); 
+         ol.disable(OutputGenerator::Man); 
+         if (!latexSourceCode)
+         {
+          ol.disable(OutputGenerator::Latex);
+        }
           QCString lineStr,anchorStr;
           anchorStr.sprintf("l%05d",md->getStartBodyLine());
           //printf("Write object link to %s\n",md->getBodyDef()->getSourceFileBase().data());
@@ -794,7 +907,11 @@ void Definition::_writeSourceRefList(OutputList &ol,const char *scopeName,
 
           // for the other output formats just mention the name
           ol.pushGeneratorState();
-          ol.disable(OutputGenerator::Html);
+           ol.disable(OutputGenerator::Html);
+           if (latexSourceCode)
+          {
+            ol.disable(OutputGenerator::Latex);
+           }
           ol.docify(name);
           ol.popGeneratorState();
         }
@@ -802,7 +919,14 @@ void Definition::_writeSourceRefList(OutputList &ol,const char *scopeName,
         {
           // for HTML write a real link
           ol.pushGeneratorState();
-          ol.disableAllBut(OutputGenerator::Html);
+          //ol.disableAllBut(OutputGenerator::Html); 
+          ol.disable(OutputGenerator::RTF); 
+          ol.disable(OutputGenerator::Man); 
+          if (!latexSourceCode)
+          {
+            ol.disable(OutputGenerator::Latex);
+           }
+     
           ol.writeObjectLink(md->getReference(),
                              md->getOutputFileBase(),
                              md->anchor(),name);
@@ -811,6 +935,10 @@ void Definition::_writeSourceRefList(OutputList &ol,const char *scopeName,
           // for the other output formats just mention the name
           ol.pushGeneratorState();
           ol.disable(OutputGenerator::Html);
+           if (latexSourceCode)
+           {
+            ol.disable(OutputGenerator::Latex);
+           }
           ol.docify(name);
           ol.popGeneratorState();
         }
@@ -852,8 +980,9 @@ bool Definition::hasDocumentation() const
   //static bool sourceBrowser = Config_getBool("SOURCE_BROWSER");
   makeResident();
   bool hasDocs = 
-         (m_impl->details && !m_impl->details->doc.isEmpty()) || // has detailed docs
-         (m_impl->brief && !m_impl->brief->doc.isEmpty())     || // has brief description
+         (m_impl->details    && !m_impl->details->doc.isEmpty())    || // has detailed docs
+         (m_impl->brief      && !m_impl->brief->doc.isEmpty())      || // has brief description
+         (m_impl->inbodyDocs && !m_impl->inbodyDocs->doc.isEmpty()) || // has inbody docs
          extractAll //||                   // extract everything
   //       (sourceBrowser && m_impl->body && 
   //        m_impl->body->startLine!=-1 && m_impl->body->fileDef)
@@ -865,8 +994,9 @@ bool Definition::hasUserDocumentation() const
 {
   makeResident();
   bool hasDocs = 
-         (m_impl->details && !m_impl->details->doc.isEmpty()) ||
-         (m_impl->brief   && !m_impl->brief->doc.isEmpty());
+         (m_impl->details    && !m_impl->details->doc.isEmpty()) ||
+         (m_impl->brief      && !m_impl->brief->doc.isEmpty())   ||
+         (m_impl->inbodyDocs && !m_impl->inbodyDocs->doc.isEmpty());
   return hasDocs;
 }
 
@@ -913,7 +1043,6 @@ void Definition::addSourceReferences(MemberDef *md)
     }
     if (m_impl->sourceRefsDict->find(name)==0)
     {
-      //printf("Adding reference %s->%s\n",md->name().data(),name.data());
       m_impl->sourceRefsDict->inSort(name,md);
     }
   }
@@ -929,27 +1058,55 @@ void Definition::addInnerCompound(Definition *)
   err("Error: Definition::addInnerCompound() called\n");
 }
 
-QCString Definition::qualifiedName() 
+QCString Definition::qualifiedName() const
 {
+  static int count=0;
+  count++;
   makeResident();
-  if (!m_impl->qualifiedName.isEmpty()) return m_impl->qualifiedName;
+  if (!m_impl->qualifiedName.isEmpty()) 
+  {
+    count--;
+    return m_impl->qualifiedName;
+  }
+#if 0
+  if (count>20)
+  {
+    printf("Definition::qualifiedName() Infinite recursion detected! Type=%d\n",definitionType());
+    printf("Trace:\n");
+    Definition *d = (Definition *)this;
+    for (int i=0;d && i<20;i++)
+    {
+      printf("  %s\n",d->name().data());
+      d = d->getOuterScope();
+    }
+  }
+#endif
   
-  //printf("start Definition::qualifiedName() localName=%s\n",m_localName.data());
+  //printf("start %s::qualifiedName() localName=%s\n",name().data(),m_impl->localName.data());
   if (m_impl->outerScope==0) 
   {
-    if (m_impl->localName=="<globalScope>") return "";
-    else return m_impl->localName; 
+    if (m_impl->localName=="<globalScope>") 
+    {
+      count--;
+      return "";
+    }
+    else 
+    {
+      count--;
+      return m_impl->localName; 
+    }
   }
 
   if (m_impl->outerScope->name()=="<globalScope>")
   {
-    m_impl->qualifiedName = m_impl->localName.copy();
+    m_impl->qualifiedName = m_impl->localName;
   }
   else
   {
     m_impl->qualifiedName = m_impl->outerScope->qualifiedName()+"::"+m_impl->localName;
   }
-  //printf("end Definition::qualifiedName()=%s\n",m_qualifiedName.data());
+  //printf("end %s::qualifiedName()=%s\n",name().data(),m_impl->qualifiedName.data());
+  count--;
   return m_impl->qualifiedName;
 };
 
@@ -1068,7 +1225,9 @@ void Definition::writePathFragment(OutputList &ol) const
     if (m_impl->outerScope->definitionType()==Definition::TypeClass ||
         m_impl->outerScope->definitionType()==Definition::TypeNamespace)
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
+      if (Config_getBool("OPTIMIZE_OUTPUT_JAVA") ||
+          Config_getBool("OPTIMIZE_OUTPUT_VHDL")
+         )
       {
         ol.writeString(".");
       }
@@ -1112,9 +1271,9 @@ void Definition::writeNavigationPath(OutputList &ol) const
   ol.pushGeneratorState();
   ol.disableAllBut(OutputGenerator::Html);
 
-  ol.writeString("<div class=\"nav\">\n");
+  ol.writeString("  <div class=\"navpath\">");
   writePathFragment(ol);
-  ol.writeString("</div>\n");
+  ol.writeString("\n  </div>\n");
 
   ol.popGeneratorState();
 }
@@ -1124,6 +1283,8 @@ QCString Definition::symbolName() const
   return m_symbolName; 
 }
 
+//----------------------
+
 QCString Definition::documentation() const 
 { 
   makeResident();
@@ -1142,6 +1303,8 @@ QCString Definition::docFile() const
   return m_impl->details ? m_impl->details->file : QCString("<"+m_name+">"); 
 }
 
+//----------------------
+
 QCString Definition::briefDescription() const 
 { 
   makeResident();
@@ -1158,8 +1321,11 @@ QCString Definition::briefDescriptionAsTooltip() const
       static bool reentering=FALSE; 
       if (!reentering)
       {
+        MemberDef *md = definitionType()==TypeMember ? (MemberDef*)this : 0;
+        const Definition *scope = definitionType()==TypeMember ? getOuterScope() : this;
         reentering=TRUE; // prevent requests for tooltips while parsing a tooltip
         m_impl->brief->tooltip = parseCommentAsText(
+            scope,md,
             m_impl->brief->doc,
             m_impl->brief->file,
             m_impl->brief->line);
@@ -1183,6 +1349,29 @@ QCString Definition::briefFile() const
   return m_impl->brief ? m_impl->brief->file : QCString("<"+m_name+">"); 
 }
 
+//----------------------
+
+QCString Definition::inbodyDocumentation() const
+{
+  makeResident();
+  return m_impl->inbodyDocs ? m_impl->inbodyDocs->doc : QCString(""); 
+}
+
+int Definition::inbodyLine() const 
+{ 
+  makeResident();
+  return m_impl->inbodyDocs ? m_impl->inbodyDocs->line : 1; 
+}
+
+QCString Definition::inbodyFile() const 
+{ 
+  makeResident();
+  return m_impl->inbodyDocs ? m_impl->inbodyDocs->file : QCString("<"+m_name+">"); 
+}
+
+
+//----------------------
+
 QCString Definition::getDefFileName() const 
 { 
   makeResident();
@@ -1217,6 +1406,11 @@ bool Definition::isVisible() const
   return isLinkable() && !m_impl->hidden; 
 }
 
+bool Definition::isArtificial() const
+{
+  return m_impl->isArtificial;
+}
+
 QCString Definition::getReference() const 
 { 
   makeResident();
@@ -1288,6 +1482,12 @@ void Definition::setHidden(bool b)
   m_impl->hidden = m_impl->hidden || b; 
 }
 
+void Definition::setArtificial(bool b)
+{
+  makeResident();
+  m_impl->isArtificial = b;
+}
+
 void Definition::setLocalName(const QCString name) 
 { 
   makeResident();
@@ -1311,6 +1511,7 @@ void Definition::flushToDisk() const
   marshalItemInfoList (Doxygen::symbolStorage,m_impl->xrefListItems);
   marshalGroupList    (Doxygen::symbolStorage,m_impl->partOfGroups);
   marshalDocInfo      (Doxygen::symbolStorage,m_impl->details);
+  marshalDocInfo      (Doxygen::symbolStorage,m_impl->inbodyDocs);
   marshalBriefInfo    (Doxygen::symbolStorage,m_impl->brief);
   marshalBodyInfo     (Doxygen::symbolStorage,m_impl->body);
   marshalQCString     (Doxygen::symbolStorage,m_impl->docSignatures);
@@ -1318,6 +1519,7 @@ void Definition::flushToDisk() const
   marshalQCString     (Doxygen::symbolStorage,m_impl->qualifiedName);
   marshalQCString     (Doxygen::symbolStorage,m_impl->ref);
   marshalBool         (Doxygen::symbolStorage,m_impl->hidden);
+  marshalBool         (Doxygen::symbolStorage,m_impl->isArtificial);
   marshalObjPointer   (Doxygen::symbolStorage,m_impl->outerScope);
   marshalQCString     (Doxygen::symbolStorage,m_impl->defFileName);
   marshalInt          (Doxygen::symbolStorage,m_impl->defLine);
@@ -1341,6 +1543,7 @@ void Definition::loadFromDisk() const
   m_impl->xrefListItems   = unmarshalItemInfoList (Doxygen::symbolStorage);
   m_impl->partOfGroups    = unmarshalGroupList    (Doxygen::symbolStorage);
   m_impl->details         = unmarshalDocInfo      (Doxygen::symbolStorage);
+  m_impl->inbodyDocs      = unmarshalDocInfo      (Doxygen::symbolStorage);
   m_impl->brief           = unmarshalBriefInfo    (Doxygen::symbolStorage);
   m_impl->body            = unmarshalBodyInfo     (Doxygen::symbolStorage);
   m_impl->docSignatures   = unmarshalQCString     (Doxygen::symbolStorage);
@@ -1348,6 +1551,7 @@ void Definition::loadFromDisk() const
   m_impl->qualifiedName   = unmarshalQCString     (Doxygen::symbolStorage);
   m_impl->ref             = unmarshalQCString     (Doxygen::symbolStorage);
   m_impl->hidden          = unmarshalBool         (Doxygen::symbolStorage);
+  m_impl->isArtificial    = unmarshalBool         (Doxygen::symbolStorage);
   m_impl->outerScope      = (Definition *)unmarshalObjPointer   (Doxygen::symbolStorage);
   m_impl->defFileName     = unmarshalQCString     (Doxygen::symbolStorage);
   m_impl->defLine         = unmarshalInt          (Doxygen::symbolStorage);
