@@ -2,7 +2,7 @@
  *
  * $Id: filedef.cpp,v 1.55 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -33,6 +33,11 @@
 #include "htags.h"
 #include "parserintf.h"
 #include "portable.h"
+#include "vhdldocgen.h"
+#include "debug.h"
+#include "layout.h"
+
+//---------------------------------------------------------------------------
 
 class DevNullCodeDocInterface : public CodeOutputInterface
 {
@@ -53,6 +58,8 @@ class DevNullCodeDocInterface : public CodeOutputInterface
     virtual void linkableSymbol(int, const char *,Definition *,Definition *) {}
 };
 
+//---------------------------------------------------------------------------
+
 /*! create a new file definition, where \a p is the file path, 
     \a nm the file name, and \a ref is an HTML anchor name if the
     file was read from a tag file or 0 otherwise
@@ -152,21 +159,22 @@ void FileDef::findSectionsInDocumentation()
   }
 }
 
-void FileDef::writeDetailedDocumentation(OutputList &ol)
+void FileDef::writeDetailedDescription(OutputList &ol,const QCString &title)
 {
   if ((!briefDescription().isEmpty() && Config_getBool("REPEAT_BRIEF")) || 
-      !documentation().isEmpty() 
+      !documentation().isEmpty() ||
+      (Config_getBool("SOURCE_BROWSER") && getStartBodyLine()!=-1 && getBodyDef())
      )
   {
     ol.writeRuler();
     ol.pushGeneratorState();
-    ol.disable(OutputGenerator::Latex);
-    ol.disable(OutputGenerator::RTF);
-    ol.writeAnchor(0,"_details"); 
+    ol.disable(OutputGenerator::Html);
+      ol.writeAnchor(0,"_details"); 
     ol.popGeneratorState();
     ol.startGroupHeader();
-    ol.parseText(theTranslator->trDetailedDescription());
+    ol.parseText(title);
     ol.endGroupHeader();
+
     ol.startTextBlock();
     if (!briefDescription().isEmpty() && Config_getBool("REPEAT_BRIEF"))
     {
@@ -177,6 +185,7 @@ void FileDef::writeDetailedDocumentation(OutputList &ol)
     {
       ol.pushGeneratorState();
         ol.disable(OutputGenerator::Man);
+        ol.disable(OutputGenerator::RTF);
         ol.newParagraph();
         ol.enableAll();
         ol.disableAllBut(OutputGenerator::Man);
@@ -185,8 +194,6 @@ void FileDef::writeDetailedDocumentation(OutputList &ol)
     }
     if (!documentation().isEmpty())
     {
-      //if (doc.at(dl-1)!='.' && doc.at(dl-1)!='!' && doc.at(dl-1)!='?') 
-      //  doc+='.';
       ol.parseDoc(docFile(),docLine(),this,0,documentation()+"\n",TRUE,FALSE);
     }
     //printf("Writing source ref for file %s\n",name().data());
@@ -209,108 +216,38 @@ void FileDef::writeDetailedDocumentation(OutputList &ol)
   }
 }
 
-/*! Write the documentation page for this file to the file of output
-    generators \a ol. 
-*/
-void FileDef::writeDocumentation(OutputList &ol)
+void FileDef::writeBriefDescription(OutputList &ol)
 {
-  //funcList->countDecMembers();
-  
-  //QCString fn = name();
-  //if (Config_getBool("FULL_PATH_NAMES"))
-  //{
-  //  fn.prepend(stripFromPath(getPath().copy()));
-  //}
-
-  //printf("WriteDocumentation diskname=%s\n",diskname.data());
-  
-  QCString versionTitle;
-  if (!fileVersion.isEmpty())
-  {
-    versionTitle=("("+fileVersion+")");
-  }
-  QCString title = docname+versionTitle;
-  QCString pageTitle=theTranslator->trFileReference(docname);
-  startFile(ol,getOutputFileBase(),name(),pageTitle,HLI_FileVisible);
-
-  if (Config_getBool("SHOW_DIRECTORIES") && getDirDef())
-  {
-    getDirDef()->writeNavigationPath(ol);
-    QCString pageTitleShort=theTranslator->trFileReference(name());
-    startTitle(ol,getOutputFileBase());
-    ol.pushGeneratorState();
-      ol.disableAllBut(OutputGenerator::Html);
-      ol.parseText(pageTitleShort); // Html only
-      ol.enableAll();
-      ol.disable(OutputGenerator::Html);
-      ol.parseText(pageTitle); // other output formats
-    ol.popGeneratorState();
-    addGroupListToTitle(ol,this);
-    endTitle(ol,getOutputFileBase(),title);
-  }
-  else
-  {
-    startTitle(ol,getOutputFileBase());
-    ol.parseText(pageTitle);
-    addGroupListToTitle(ol,this);
-    endTitle(ol,getOutputFileBase(),title);
-  }
-  if (!fileVersion.isEmpty())
-  {
-    ol.disableAllBut(OutputGenerator::Html);
-    ol.startProjectNumber();
-    ol.docify(versionTitle);
-    ol.endProjectNumber();
-    ol.enableAll();
-  }
-  
-  if (Config_getBool("SEARCHENGINE"))
-  {
-    Doxygen::searchIndex->setCurrentDoc(pageTitle,getOutputFileBase());
-    Doxygen::searchIndex->addWord(localName(),TRUE);
-  }
-  
-  if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
-  {
-    Doxygen::tagFile << "  <compound kind=\"file\">" << endl;
-    Doxygen::tagFile << "    <name>" << convertToXML(name()) << "</name>" << endl;
-    Doxygen::tagFile << "    <path>" << convertToXML(getPath()) << "</path>" << endl;
-    Doxygen::tagFile << "    <filename>" 
-                     << convertToXML(getOutputFileBase()) 
-                     << "</filename>" << endl;
-  }
-  
-  if (Config_getBool("DETAILS_AT_TOP"))
-  {
-    ol.startTextBlock(); 
-    writeDetailedDocumentation(ol);
-    ol.endTextBlock();
-
-    ol.pushGeneratorState();
-    ol.disable(OutputGenerator::Man);
-    ol.disable(OutputGenerator::RTF);
-    ol.newParagraph();
-    ol.popGeneratorState();
-  }
-  else if (!briefDescription().isEmpty()) 
+  if (!briefDescription().isEmpty()) 
   {
     ol.parseDoc(briefFile(),briefLine(),this,0,briefDescription(),TRUE,FALSE);
-    //ol.writeString(" \n");
-    ol.disableAllBut(OutputGenerator::Html);
-    ol.startTextLink(0,"_details");
-    ol.parseText(theTranslator->trMore());
-    ol.endTextLink();
-    ol.enableAll();
+    ol.pushGeneratorState();
+    ol.disable(OutputGenerator::RTF);
+    ol.writeString(" \n");
+    ol.enable(OutputGenerator::RTF);
+
+    if (Config_getBool("REPEAT_BRIEF") ||
+        !documentation().isEmpty()
+       )
+    {
+      ol.disableAllBut(OutputGenerator::Html);
+      ol.startTextLink(0,"_details");
+      ol.parseText(theTranslator->trMore());
+      ol.endTextLink();
+    }
+    ol.popGeneratorState();
 
     ol.pushGeneratorState();
-    ol.disable(OutputGenerator::Man);
     ol.disable(OutputGenerator::RTF);
     ol.newParagraph();
     ol.popGeneratorState();
   }
   ol.writeSynopsis();
- 
-  if (Config_getBool("SHOW_INCLUDE_FILES") && includeList && 
+}
+
+void FileDef::writeIncludeFiles(OutputList &ol)
+{
+  if (/*Config_getBool("SHOW_INCLUDE_FILES") &&*/ includeList && 
       includeList->count()>0)
   {
     ol.startTextBlock(TRUE);
@@ -388,8 +325,11 @@ void FileDef::writeDocumentation(OutputList &ol)
     }
     ol.endTextBlock();
   }
-  
-  if (Config_getBool("HAVE_DOT") && Config_getBool("INCLUDE_GRAPH"))
+}
+
+void FileDef::writeIncludeGraph(OutputList &ol)
+{
+  if (Config_getBool("HAVE_DOT") /*&& Config_getBool("INCLUDE_GRAPH")*/)
   {
     //printf("Graph for file %s\n",name().data());
     DotInclDepGraph incDepGraph(this,FALSE);
@@ -406,8 +346,11 @@ void FileDef::writeDocumentation(OutputList &ol)
     }
     //incDepGraph.writeGraph(Config_getString("HTML_OUTPUT"),fd->getOutputFileBase());
   }
+}
 
-  if (Config_getBool("HAVE_DOT") && Config_getBool("INCLUDED_BY_GRAPH"))
+void FileDef::writeIncludedByGraph(OutputList &ol)
+{
+  if (Config_getBool("HAVE_DOT") /*&& Config_getBool("INCLUDED_BY_GRAPH")*/)
   {
     //printf("Graph for file %s\n",name().data());
     DotInclDepGraph incDepGraph(this,TRUE);
@@ -424,7 +367,11 @@ void FileDef::writeDocumentation(OutputList &ol)
     }
     //incDepGraph.writeGraph(Config_getString("HTML_OUTPUT"),fd->getOutputFileBase());
   }
+}
 
+
+void FileDef::writeSourceLink(OutputList &ol)
+{
   //printf("%s: generateSourceFile()=%d\n",name().data(),generateSourceFile());
   if (generateSourceFile())
   {
@@ -435,55 +382,50 @@ void FileDef::writeDocumentation(OutputList &ol)
     ol.endTextLink();
     ol.enableAll();
   }
-  
+}
+
+void FileDef::writeNamespaceDeclarations(OutputList &ol,const QCString &title)
+{
+  // write list of namespaces
+  if (namespaceSDict) namespaceSDict->writeDeclaration(ol,title);
+}
+
+void FileDef::writeClassDeclarations(OutputList &ol,const QCString &title)
+{
+  // write list of classes
+  if (classSDict) classSDict->writeDeclaration(ol,0,title,FALSE);
+}
+
+void FileDef::startMemberDeclarations(OutputList &ol)
+{
   ol.startMemberSections();
+}
 
-  if (namespaceSDict && namespaceSDict->count()>0)
+void FileDef::endMemberDeclarations(OutputList &ol)
+{
+  ol.endMemberSections();
+}
+
+void FileDef::startMemberDocumentation(OutputList &ol)
+{
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
-    NamespaceSDict::Iterator ndi(*namespaceSDict);
-    NamespaceDef *nd;
-    bool found=FALSE;
-    for (ndi.toFirst();(nd=ndi.current());++ndi)
-    {
-      if (nd->name().find('@')==-1)
-      {
-        if (!found)
-        {
-          ol.startMemberHeader();
-          ol.parseText(theTranslator->trNamespaces());
-          ol.endMemberHeader();
-          ol.startMemberList();
-          found=TRUE;
-        }
-        ol.startMemberItem(0);
-        ol.writeString("namespace ");
-        ol.insertMemberAlign();
-        if (nd->isLinkable()) 
-        {
-          ol.writeObjectLink(nd->getReference(),
-              nd->getOutputFileBase(),
-              0,
-              nd->displayName()
-          );
-          if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
-          {
-            Doxygen::tagFile << "    <namespace>" << convertToXML(nd->name()) << "</namespace>" << endl;
-          }
-        }
-        else
-        {
-          ol.startBold();
-          ol.docify(nd->displayName());
-          ol.endBold();
-        }
-        ol.endMemberItem();
-      }
-    }
-    if (found) ol.endMemberList();
+    ol.disable(OutputGenerator::Html);
+    Doxygen::suppressDocWarnings = TRUE;
   }
+}
 
-  if (classSDict) classSDict->writeDeclaration(ol);
-  
+void FileDef::endMemberDocumentation(OutputList &ol)
+{
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
+  {
+    ol.enable(OutputGenerator::Html);
+    Doxygen::suppressDocWarnings = FALSE;
+  }
+}
+
+void FileDef::writeMemberGroups(OutputList &ol)
+{
   /* write user defined member groups */
   if (memberGroupSDict)
   {
@@ -498,30 +440,191 @@ void FileDef::writeDocumentation(OutputList &ol)
       }
     }
   }
+}
 
-  //allMemberList.writeDeclarations(ol,0,0,this,0,0,0);
-  writeMemberDeclarations(ol,MemberList::decDefineMembers,theTranslator->trDefines());
-  writeMemberDeclarations(ol,MemberList::decProtoMembers,theTranslator->trFuncProtos());
-  writeMemberDeclarations(ol,MemberList::decTypedefMembers,theTranslator->trTypedefs());
-  writeMemberDeclarations(ol,MemberList::decEnumMembers,theTranslator->trEnumerations());
-  writeMemberDeclarations(ol,MemberList::decFuncMembers,theTranslator->trFunctions());
-  writeMemberDeclarations(ol,MemberList::decVarMembers,theTranslator->trVariables());
-  ol.endMemberSections();
-
-  if (!Config_getBool("DETAILS_AT_TOP"))
-  {
-    writeDetailedDocumentation(ol);
-  }
-
-  writeMemberDocumentation(ol);
-  
+void FileDef::writeAuthorSection(OutputList &ol)
+{
   // write Author section (Man only)
+  ol.pushGeneratorState();
   ol.disableAllBut(OutputGenerator::Man);
   ol.startGroupHeader();
   ol.parseText(theTranslator->trAuthor(TRUE,TRUE));
   ol.endGroupHeader();
   ol.parseText(theTranslator->trGeneratedAutomatically(Config_getString("PROJECT_NAME")));
-  ol.enableAll();
+  ol.popGeneratorState();
+}
+
+/*! Write the documentation page for this file to the file of output
+    generators \a ol. 
+*/
+void FileDef::writeDocumentation(OutputList &ol)
+{
+  //funcList->countDecMembers();
+  
+  //QCString fn = name();
+  //if (Config_getBool("FULL_PATH_NAMES"))
+  //{
+  //  fn.prepend(stripFromPath(getPath().copy()));
+  //}
+
+  //printf("WriteDocumentation diskname=%s\n",diskname.data());
+  
+  QCString versionTitle;
+  if (!fileVersion.isEmpty())
+  {
+    versionTitle=("("+fileVersion+")");
+  }
+  QCString title = docname+versionTitle;
+  QCString pageTitle=theTranslator->trFileReference(docname);
+
+  if (Config_getBool("SHOW_DIRECTORIES") && getDirDef())
+  {
+    startFile(ol,getOutputFileBase(),name(),pageTitle,HLI_FileVisible,TRUE);
+    getDirDef()->writeNavigationPath(ol);
+    ol.endQuickIndices();
+    ol.startContents();
+    QCString pageTitleShort=theTranslator->trFileReference(name());
+    startTitle(ol,getOutputFileBase());
+    ol.pushGeneratorState();
+      ol.disableAllBut(OutputGenerator::Html);
+      ol.parseText(pageTitleShort); // Html only
+      ol.enableAll();
+      ol.disable(OutputGenerator::Html);
+      ol.parseText(pageTitle); // other output formats
+    ol.popGeneratorState();
+    addGroupListToTitle(ol,this);
+    endTitle(ol,getOutputFileBase(),title);
+  }
+  else
+  {
+    startFile(ol,getOutputFileBase(),name(),pageTitle,HLI_FileVisible);
+    startTitle(ol,getOutputFileBase());
+    ol.parseText(pageTitle);
+    addGroupListToTitle(ol,this);
+    endTitle(ol,getOutputFileBase(),title);
+  }
+  if (!fileVersion.isEmpty())
+  {
+    ol.disableAllBut(OutputGenerator::Html);
+    ol.startProjectNumber();
+    ol.docify(versionTitle);
+    ol.endProjectNumber();
+    ol.enableAll();
+  }
+  
+  if (Config_getBool("SEARCHENGINE"))
+  {
+    Doxygen::searchIndex->setCurrentDoc(pageTitle,getOutputFileBase());
+    Doxygen::searchIndex->addWord(localName(),TRUE);
+  }
+  
+  if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+  {
+    Doxygen::tagFile << "  <compound kind=\"file\">" << endl;
+    Doxygen::tagFile << "    <name>" << convertToXML(name()) << "</name>" << endl;
+    Doxygen::tagFile << "    <path>" << convertToXML(getPath()) << "</path>" << endl;
+    Doxygen::tagFile << "    <filename>" 
+                     << convertToXML(getOutputFileBase()) 
+                     << "</filename>" << endl;
+  }
+
+  //---------------------------------------- start flexible part -------------------------------
+  
+  QListIterator<LayoutDocEntry> eli(
+      LayoutDocManager::instance().docEntries(LayoutDocManager::File));
+  LayoutDocEntry *lde;
+  for (eli.toFirst();(lde=eli.current());++eli)
+  {
+    switch (lde->kind())
+    {
+      case LayoutDocEntry::BriefDesc: 
+        writeBriefDescription(ol);
+        break; 
+      case LayoutDocEntry::MemberDeclStart: 
+        startMemberDeclarations(ol);
+        break; 
+      case LayoutDocEntry::FileIncludes:
+        writeIncludeFiles(ol);
+        break;
+      case LayoutDocEntry::FileIncludeGraph:
+        writeIncludeGraph(ol);
+        break;
+      case LayoutDocEntry::FileIncludedByGraph:
+        writeIncludedByGraph(ol);
+        break;
+      case LayoutDocEntry::FileSourceLink:
+        writeSourceLink(ol);
+        break;
+      case LayoutDocEntry::FileClasses: 
+        {
+          LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
+          writeClassDeclarations(ol,ls->title);
+        }
+        break; 
+      case LayoutDocEntry::FileNamespaces: 
+        {
+          LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
+          writeNamespaceDeclarations(ol,ls->title);
+        }
+        break; 
+      case LayoutDocEntry::MemberGroups: 
+        writeMemberGroups(ol);
+        break; 
+      case LayoutDocEntry::MemberDecl: 
+        {
+          LayoutDocEntryMemberDecl *lmd = (LayoutDocEntryMemberDecl*)lde;
+          writeMemberDeclarations(ol,lmd->type,lmd->title);
+        }
+        break; 
+      case LayoutDocEntry::MemberDeclEnd: 
+        endMemberDeclarations(ol);
+        break;
+      case LayoutDocEntry::DetailedDesc: 
+        {
+          LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
+          writeDetailedDescription(ol,ls->title);
+        }
+        break;
+      case LayoutDocEntry::MemberDefStart: 
+        startMemberDocumentation(ol);
+        break; 
+      case LayoutDocEntry::MemberDef: 
+        {
+          LayoutDocEntryMemberDef *lmd = (LayoutDocEntryMemberDef*)lde;
+          writeMemberDocumentation(ol,lmd->type,lmd->title);
+        }
+        break;
+      case LayoutDocEntry::MemberDefEnd: 
+        endMemberDocumentation(ol);
+        break;
+      case LayoutDocEntry::AuthorSection: 
+        writeAuthorSection(ol);
+        break;
+      case LayoutDocEntry::ClassIncludes:
+      case LayoutDocEntry::ClassInheritanceGraph:
+      case LayoutDocEntry::ClassNestedClasses:
+      case LayoutDocEntry::ClassCollaborationGraph:
+      case LayoutDocEntry::ClassAllMembersLink:
+      case LayoutDocEntry::ClassUsedFiles:
+      case LayoutDocEntry::NamespaceNestedNamespaces:
+      case LayoutDocEntry::NamespaceClasses:
+      case LayoutDocEntry::GroupClasses: 
+      case LayoutDocEntry::GroupNamespaces:
+      case LayoutDocEntry::GroupDirs: 
+      case LayoutDocEntry::GroupNestedGroups: 
+      case LayoutDocEntry::GroupFiles:
+      case LayoutDocEntry::GroupGraph: 
+      case LayoutDocEntry::GroupPageDocs:
+      case LayoutDocEntry::DirSubDirs:
+      case LayoutDocEntry::DirFiles:
+      case LayoutDocEntry::DirGraph:
+        err("Internal inconsistency: member %d should not be part of "
+            "LayoutDocManager::File entry list\n",lde->kind());
+        break;
+    }
+  }
+
+  //---------------------------------------- end flexible part -------------------------------
 
   if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
   {
@@ -539,26 +642,6 @@ void FileDef::writeDocumentation(OutputList &ol)
   }
 }
 
-void FileDef::writeMemberDocumentation(OutputList &ol)
-{
-  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
-  {
-    ol.disable(OutputGenerator::Html);
-  }
-
-  writeMemberDocumentation(ol,MemberList::docDefineMembers,theTranslator->trDefineDocumentation());
-  writeMemberDocumentation(ol,MemberList::docProtoMembers,theTranslator->trFunctionPrototypeDocumentation());
-  writeMemberDocumentation(ol,MemberList::docTypedefMembers,theTranslator->trTypedefDocumentation());
-  writeMemberDocumentation(ol,MemberList::docEnumMembers,theTranslator->trEnumerationTypeDocumentation());
-  writeMemberDocumentation(ol,MemberList::docFuncMembers,theTranslator->trFunctionDocumentation());
-  writeMemberDocumentation(ol,MemberList::docVarMembers,theTranslator->trVariableDocumentation());
-
-  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
-  {
-    ol.enable(OutputGenerator::Html);
-  }
-}
-
 void FileDef::writeMemberPages(OutputList &ol)
 {
   ol.pushGeneratorState();
@@ -624,34 +707,42 @@ void FileDef::writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const
 void FileDef::writeSource(OutputList &ol)
 {
   static bool filterSourceFiles = Config_getBool("FILTER_SOURCE_FILES");
+  static bool latexSourceCode   = Config_getBool("LATEX_SOURCE_CODE");
   QCString title = docname;
   if (!fileVersion.isEmpty())
   {
     title+=(" ("+fileVersion+")");
   }
   QCString pageTitle = theTranslator->trSourceFile(title);
-  ol.disableAllBut(OutputGenerator::Html);
-  startFile(ol,getSourceFileBase(),0,pageTitle,HLI_FileVisible);
+  ol.disable(OutputGenerator::Man);
+  ol.disable(OutputGenerator::RTF);
+  if (!latexSourceCode) ol.disable(OutputGenerator::Latex);
 
   if (Config_getBool("SHOW_DIRECTORIES") && getDirDef())
   {
+    startFile(ol,getSourceFileBase(),0,pageTitle,HLI_FileVisible,TRUE);
     getDirDef()->writeNavigationPath(ol);
+    ol.endQuickIndices();
+    ol.startContents();
     startTitle(ol,getOutputFileBase());
     ol.parseText(name());
     endTitle(ol,getOutputFileBase(),title);
   }
   else
   {
-    startTitle(ol,0);
+    startFile(ol,getSourceFileBase(),0,pageTitle,HLI_FileVisible,TRUE);
+    startTitle(ol,getSourceFileBase());
     ol.parseText(title);
-    endTitle(ol,0,0);
+    endTitle(ol,getSourceFileBase(),0);
   }
 
   if (isLinkable())
   {
+    if (latexSourceCode) ol.disable(OutputGenerator::Latex);
     ol.startTextLink(getOutputFileBase(),0);
     ol.parseText(theTranslator->trGotoDocumentation());
     ol.endTextLink();
+    if (latexSourceCode) ol.enable(OutputGenerator::Latex);
   }
 
   ParserInterface *pIntf = Doxygen::parserManager->getParser(getDefFileExtension());
@@ -747,10 +838,6 @@ void FileDef::insertMember(MemberDef *md)
       break;
     case MemberDef::EnumValue:    // enum values are shown inside their enums
       break;
-    case MemberDef::Prototype:    
-      addMemberToList(MemberList::decProtoMembers,md);
-      addMemberToList(MemberList::docProtoMembers,md);
-      break;
     case MemberDef::Define:       
       addMemberToList(MemberList::decDefineMembers,md);
       addMemberToList(MemberList::docDefineMembers,md);
@@ -807,7 +894,7 @@ void FileDef::addSourceRef(int line,Definition *d,MemberDef *md)
     srcDefDict->insert(line,d);
     if (md) srcMemberDict->insert(line,md);
     //printf("Adding member %s with anchor %s at line %d to file %s\n",
-    //    d->name().data(),anchor,line,name().data());
+    //    md->name().data(),md->anchor().data(),line,name().data());
   }
 }
 
@@ -915,6 +1002,7 @@ void FileDef::addIncludedUsingDirectives()
       {
         if (ii->fileDef && ii->fileDef!=this)
         {
+          // add using directives
           NamespaceSDict *unl = ii->fileDef->usingDirList;
           if (unl)
           {
@@ -932,6 +1020,25 @@ void FileDef::addIncludedUsingDirectives()
               }
             }
           }
+          // add using declarations
+          SDict<Definition> *udl = ii->fileDef->usingDeclList;
+          if (udl)
+          {
+            SDict<Definition>::Iterator udi(*udl);
+            Definition *d;
+            for (udi.toLast();(d=udi.current());--udi)
+            {
+              //printf("Adding using declaration %s\n",d->name().data());
+              if (usingDeclList==0)
+              {
+                usingDeclList = new SDict<Definition>(17);
+              }
+              if (usingDeclList->find(d->qualifiedName())==0)
+              {
+                usingDeclList->prepend(d->qualifiedName(),d);
+              }
+            }
+          }
         }
       }
     }
@@ -1309,7 +1416,9 @@ void FileDef::acquireFileVersion()
   if (!vercmd.isEmpty()) 
   {
     msg("Version of %s : ",filepath.data());
-    FILE *f=portable_popen(vercmd+" \""+filepath+"\"","r");
+    QCString cmd = vercmd+" \""+filepath+"\"";
+    Debug::print(Debug::ExtCmd,0,"Executing popen(`%s`)\n",cmd.data());
+    FILE *f=portable_popen(cmd,"r");
     if (!f)
     {
       err("Error: could not execute %s\n",vercmd.data());
@@ -1340,7 +1449,7 @@ QCString FileDef::getSourceFileBase() const
   }
   else
   {
-    return convertNameToFile(diskname+"-source"); 
+    return convertNameToFile(diskname)+"_source"; 
   }
 }
 
@@ -1353,7 +1462,7 @@ QCString FileDef::includeName() const
   }
   else
   {
-    return convertNameToFile(diskname+"-source"); 
+    return convertNameToFile(diskname)+"_source"; 
   }
 }
 
@@ -1410,8 +1519,19 @@ MemberList *FileDef::getMemberList(MemberList::ListType lt) const
 
 void FileDef::writeMemberDeclarations(OutputList &ol,MemberList::ListType lt,const QCString &title)
 {
+  static bool optVhdl = Config_getBool("OPTIMIZE_OUTPUT_VHDL");
   MemberList * ml = getMemberList(lt);
-  if (ml) ml->writeDeclarations(ol,0,0,this,0,title,0);
+  if (ml) 
+  {
+    if (optVhdl) // use specific declarations function
+    {
+      VhdlDocGen::writeVhdlDeclarations(ml,ol,0,0,this);
+    }
+    else
+    {
+      ml->writeDeclarations(ol,0,0,this,0,title,0);
+    }
+  }
 }
 
 void FileDef::writeMemberDocumentation(OutputList &ol,MemberList::ListType lt,const QCString &title)
@@ -1419,3 +1539,10 @@ void FileDef::writeMemberDocumentation(OutputList &ol,MemberList::ListType lt,co
   MemberList * ml = getMemberList(lt);
   if (ml) ml->writeDocumentation(ol,name(),this,title);
 }
+
+bool FileDef::isLinkableInProject() const
+{
+  static bool showFiles = Config_getBool("SHOW_FILES");
+  return hasDocumentation() && !isReference() && showFiles;
+}
+
