@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -28,6 +28,7 @@
 #include "htmlgen.h"
 #include "parserintf.h"
 #include "msc.h"
+#include "util.h"
 
 
 static const int NUM_HTML_LIST_TYPES = 4;
@@ -122,6 +123,8 @@ void HtmlDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Cedil:   m_t << "&" << s->letter() << "cedil;"; break;
     case DocSymbol::Ring:    m_t << "&" << s->letter() << "ring;"; break;
     case DocSymbol::Nbsp:    m_t << "&nbsp;"; break;
+    case DocSymbol::AElig:   m_t << "&AElig;"; break;
+    case DocSymbol::Aelig:   m_t << "&aelig;"; break;
     default:
                              err("Error: unknown symbol found\n");
   }
@@ -574,7 +577,7 @@ void HtmlDocVisitor::visitPre(DocSection *s)
   m_t << "<h" << s->level()+1 << ">";
   m_t << "<a class=\"anchor\" name=\"" << s->anchor();
   m_t << "\">" << endl;
-  filter(s->title());
+  filter(convertCharEntitiesToUTF8(s->title().data()));
   m_t << "</a></h" << s->level()+1 << ">\n";
 }
 
@@ -934,6 +937,11 @@ void HtmlDocVisitor::visitPre(DocParamSect *s)
       m_t << theTranslator->trReturnValues(); break;
     case DocParamSect::Exception: 
       m_t << theTranslator->trExceptions(); break;
+    case DocParamSect::TemplateParam: 
+      /* TODO: add this 
+      m_t << theTranslator->trTemplateParam(); break;
+      */
+      m_t << "Template Parameters"; break;
     default:
       ASSERT(0);
   }
@@ -1003,13 +1011,13 @@ void HtmlDocVisitor::visitPre(DocXRefItem *x)
   bool anonymousEnum = x->file()=="@";
   if (!anonymousEnum)
   {
-    m_t << "<dl compact><dt><b><a class=\"el\" href=\"" 
+    m_t << "<dl class=\"" << x->key() << "\" compact><dt><b><a class=\"el\" href=\"" 
         << x->relPath() << x->file() << Doxygen::htmlFileExtension 
         << "#" << x->anchor() << "\">";
   }
   else 
   {
-    m_t << "<dl compact><dt><b>";
+    m_t << "<dl class=\"" << x->key() << "\" compact><dt><b>";
   }
   filter(x->title());
   m_t << ":";
