@@ -383,7 +383,7 @@ static const char tabs_css[] =
 "   float            : left;\n"
 "   background       : url(\"tab_r.gif\") no-repeat right top;\n"
 "   border-bottom    : 1px solid #84B0C7;\n"
-"   font-size        : 8px;\n"
+"   font-size        : 80%;\n"
 "   font-weight      : bold;\n"
 "   text-decoration  : none;\n"
 "}\n"
@@ -417,7 +417,7 @@ static const char tabs_css[] =
 "\n"
 "DIV.tabs TD\n"
 "{\n"
-"   font-size        : 8px;\n"
+"   font-size        : 80%;\n"
 "   font-weight      : bold;\n"
 "   text-decoration  : none;\n"
 "}\n"
@@ -450,6 +450,9 @@ static const char tabs_css[] =
 "   background       : none;\n"
 "   border           : none;\n"
 "   border-bottom    : 1px solid #84B0C7;\n"
+"   text-align       : center;\n"
+"   margin           : 2px;\n"
+"   padding          : 2px;\n"
 "}\n"
 ;
 
@@ -547,10 +550,7 @@ void HtmlGenerator::init()
   }
   createSubDirs(d);
 
-  //if (Config_getBool("HTML_FANCY_TABS"))
-  {
-    writeTabData(dname);
-  }
+  writeTabData(dname);
 }
 
 void HtmlGenerator::writeStyleSheetFile(QFile &file)
@@ -576,6 +576,7 @@ static void writeDefaultHeaderFile(QTextStream &t, const char *title,
     "<title>"; 
   t << convertToHtml(title);
   t << "</title>\n";
+  t << "<link href=\"" << relPathStr << "tabs.css\" rel=\"stylesheet\" type=\"text/css\">\n";
   t << "<link ";
   t << "href=\"";
   if (Config_getString("HTML_STYLESHEET").isEmpty())
@@ -594,7 +595,6 @@ static void writeDefaultHeaderFile(QTextStream &t, const char *title,
   }
   
   t << "\" rel=\"stylesheet\" type=\"text/css\">\n";
-  t << "<link href=\"" << relPathStr << "tabs.css\" rel=\"stylesheet\" type=\"text/css\">\n";
   t << "</head><body>\n";
 }
 
@@ -778,6 +778,7 @@ void HtmlGenerator::writeStyleInfo(int part)
 
       t << defaultStyleSheet;
       endPlainFile();
+      Doxygen::indexList.addStyleSheetFile("doxygen.css");
     }
     else // write user defined style sheet
     {
@@ -796,6 +797,7 @@ void HtmlGenerator::writeStyleInfo(int part)
         t << fileStr;
         endPlainFile();
       }
+      Doxygen::indexList.addStyleSheetFile(cssfi.fileName());
     }
   }
 }
@@ -914,7 +916,7 @@ void HtmlGenerator::writeObjectLink(const char *ref,const char *f,
   t << "href=\"";
   if (ref)
   {
-    if ((dest=Doxygen::tagDestinationDict[ref])) t << relPath << *dest << "/";
+    if ((dest=Doxygen::tagDestinationDict[ref])) t << *dest << "/";
   }
   else
   {
@@ -1079,7 +1081,7 @@ void HtmlGenerator::codify(const char *str)
       {
         case '\t': spacesToNextTabStop = 
                          Config_getInt("TAB_SIZE") - (col%Config_getInt("TAB_SIZE")); 
-                   t << spaces.left(spacesToNextTabStop); 
+                   t << Doxygen::spaces.left(spacesToNextTabStop); 
                    col+=spacesToNextTabStop; 
                    break; 
         case '\n': t << "\n"; col=0; 
@@ -1738,9 +1740,6 @@ static QCString fixSpaces(const QCString &s)
   return substitute(s," ","&nbsp;");
 }
 
-#define NEW_LAYOUT
-#ifdef NEW_LAYOUT
-
 static bool quickLinkVisible(LayoutNavEntry::Kind kind)
 {
   switch (kind)
@@ -1908,325 +1907,6 @@ static void writeDefaultQuickLinks(QTextStream &t,bool compact,
   }
 }
 
-#else // old fixed layout
-
-static void writeNamespaceSubIndex(QTextStream &t,bool compact,
-                                  HighlightedItem hli,const QCString &relPath
-                                 )
-{
-  bool fortranOpt = Config_getBool("OPTIMIZE_FOR_FORTRAN");
-  startQuickIndexList(t,compact);
-  if (documentedNamespaces>0)
-  {
-    startQuickIndexItem(t,"namespaces"+Doxygen::htmlFileExtension,
-        hli==HLI_Namespaces,compact,relPath);
-    if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
-    {
-      t << fixSpaces(theTranslator->trPackages());
-    }
-    else if(fortranOpt)
-    {
-      t << theTranslator->trModulesList();
-    }
-      else
-    {
-      t << theTranslator->trNamespaceList();
-    }
-    endQuickIndexItem(t);
-  }
-  if (documentedNamespaceMembers[NMHL_All]>0)
-  {
-    startQuickIndexItem(t,"namespacemembers"+Doxygen::htmlFileExtension,
-        hli==HLI_NamespaceMembers,compact,relPath);
-    if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
-    {
-      t << fixSpaces(theTranslator->trPackageMembers());
-    }
-    else if(fortranOpt)
-    {
-      t << fixSpaces(theTranslator->trModulesMembers());
-    }
-      else
-    {
-      t << fixSpaces(theTranslator->trNamespaceMembers());
-    }
-    endQuickIndexItem(t);
-  }
-  endQuickIndexList(t,compact);
-}
-
-static void writeClassSubIndex(QTextStream &t,bool compact,
-                               HighlightedItem hli,const QCString &relPath
-                              )
-{
-  bool fortranOpt=Config_getBool("OPTIMIZE_FOR_FORTRAN");
-  bool vhdlOpt=Config_getBool("OPTIMIZE_OUTPUT_VHDL");
-  startQuickIndexList(t,compact);
-  if (annotatedClasses>0)
-  {
-    if (Config_getBool("ALPHABETICAL_INDEX"))
-    {
-      startQuickIndexItem(t,"classes"+Doxygen::htmlFileExtension,
-          hli==HLI_Classes,compact,relPath);
-      t << fixSpaces(theTranslator->trAlphabeticalList());
-      endQuickIndexItem(t);
-    }
-    startQuickIndexItem(t,"annotated"+Doxygen::htmlFileExtension,
-        hli==HLI_Annotated,compact,relPath);
-      if (fortranOpt)
-      {
-        t << fixSpaces(theTranslator->trCompoundListFortran());
-      }
-      else if (vhdlOpt)
-      {
-        t << fixSpaces(VhdlDocGen::trDesignUnitList());
-      }
-      else
-      {
-        t << fixSpaces(theTranslator->trCompoundList());
-      }
-    
-    endQuickIndexItem(t);
-  } 
-  if (hierarchyClasses>0)
-  {
-    QCString title = theTranslator->trClassHierarchy();
-    if (vhdlOpt) title = VhdlDocGen::trDesignUnitHierarchy();
-    startQuickIndexItem(t,"hierarchy"+Doxygen::htmlFileExtension,
-        hli==HLI_Hierarchy,compact,relPath);
-    t << fixSpaces(title);
-    endQuickIndexItem(t);
-  } 
-  if (documentedClassMembers[CMHL_All]>0)
-  {
-    startQuickIndexItem(t,"functions"+Doxygen::htmlFileExtension,
-        hli==HLI_Functions,compact,relPath);
-    if (fortranOpt)
-    {
-      t << fixSpaces(theTranslator->trCompoundMembersFortran());
-    }
-    else if (vhdlOpt)
-    {
-      t << fixSpaces(VhdlDocGen::trDesignUnitMembers());
-    }
-    else
-    {
-      t << fixSpaces(theTranslator->trCompoundMembers());
-    }
-    endQuickIndexItem(t);
-  } 
-  endQuickIndexList(t,compact);
-}
-
-static void writeFileSubIndex(QTextStream &t,bool compact,
-                              HighlightedItem hli,const QCString &relPath)
-{
-  startQuickIndexList(t,compact);
-  if (documentedHtmlFiles>0)
-  {
-    startQuickIndexItem(t,"files"+Doxygen::htmlFileExtension,
-        hli==HLI_Files,compact,relPath);
-    t << fixSpaces(theTranslator->trFileList());
-    endQuickIndexItem(t);
-  } 
-  if (documentedFileMembers[FMHL_All]>0)
-  {
-    startQuickIndexItem(t,"globals"+Doxygen::htmlFileExtension,
-        hli==HLI_Globals,compact,relPath);
-    t << fixSpaces(theTranslator->trFileMembers());
-    endQuickIndexItem(t);
-  } 
-  endQuickIndexList(t,compact);
-}
-
-static void writeDefaultQuickLinks(QTextStream &t,bool compact,
-                                   HighlightedItem hli,const QCString &relPath)
-{
-  bool fortranOpt = Config_getBool("OPTIMIZE_FOR_FORTRAN");
-  bool vhdlOpt    = Config_getBool("OPTIMIZE_OUTPUT_VHDL");
-  startQuickIndexList(t,compact);
-
-  if (usingTreeIndex())
-  {
-    startQuickIndexItem(t,"main"+Doxygen::htmlFileExtension,
-                        hli==HLI_Main,compact,relPath);
-  }
-  else
-  {
-    startQuickIndexItem(t,"index"+Doxygen::htmlFileExtension,
-                        hli==HLI_Main,compact,relPath);
-  }
-  t << fixSpaces(theTranslator->trMainPage());
-  endQuickIndexItem(t);
-
-  // -------------- Related pages
-  
-  if (indexedPages>0)
-  {
-    startQuickIndexItem(t,"pages"+Doxygen::htmlFileExtension,
-                        hli==HLI_Pages,compact,relPath);
-    t << fixSpaces(theTranslator->trRelatedPages());
-    endQuickIndexItem(t);
-  } 
-
-  // --------------- Modules
-
-  if (documentedGroups>0)
-  {
-    startQuickIndexItem(t,"modules"+Doxygen::htmlFileExtension,
-                        hli==HLI_Modules,compact,relPath);
-    t << fixSpaces(theTranslator->trModules());
-    endQuickIndexItem(t);
-  } 
-
-  // --------------- Namespace indices
-
-  if (documentedNamespaces>0)
-  {
-    startQuickIndexItem(t,"namespaces"+Doxygen::htmlFileExtension,
-        hli==HLI_Namespaces || hli==HLI_NamespaceMembers || hli==HLI_NamespaceVisible,
-        compact,relPath);
-    if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
-    {
-      t << fixSpaces(theTranslator->trPackages());
-    }
-    else if (fortranOpt)
-    {
-      t << theTranslator->trModules();
-    }
-    else
-    {
-      t << theTranslator->trNamespaces();
-    }
-    endQuickIndexItem(t);
-    if (!compact)
-    {
-      writeNamespaceSubIndex(t,compact,hli,relPath);
-    }
-  }
-
-
-  // -------------- Class indices
-
-  if (annotatedClasses>0)
-  {
-    static bool alphaIndex=Config_getBool("ALPHABETICAL_INDEX");
-    {
-      startQuickIndexItem(t,QCString(alphaIndex?"classes":"annotated")+Doxygen::htmlFileExtension,
-          hli==HLI_Hierarchy || hli==HLI_Classes || 
-          hli==HLI_Annotated || hli==HLI_Functions || hli==HLI_ClassVisible,
-          compact,relPath);
-    }
-    if (fortranOpt)
-    {
-      t << fixSpaces(theTranslator->trDataTypes());
-    }
-    else if (vhdlOpt)
-    {
-      t << fixSpaces(VhdlDocGen::trDesignUnits());
-    }
-    else
-    {
-      t << fixSpaces(theTranslator->trClasses());
-    }
-    endQuickIndexItem(t);
-    if (!compact)
-    {
-      writeClassSubIndex(t,compact,hli,relPath);
-    }
-  }
-
-  // -------------- File
-
-  if (documentedHtmlFiles>0)
-  {
-    startQuickIndexItem(t,"files"+Doxygen::htmlFileExtension,
-                        hli==HLI_Files || hli==HLI_Globals || hli==HLI_FileVisible,
-                        compact,relPath);
-    t << fixSpaces(theTranslator->trFile(TRUE,FALSE));
-    endQuickIndexItem(t);
-    if (!compact)
-    {
-      writeFileSubIndex(t,compact,hli,relPath);
-    }
-  } 
-
-  // -------------- Directories
-  
-  if (Config_getBool("SHOW_DIRECTORIES") && documentedDirs>0)
-  {
-    startQuickIndexItem(t,"dirs"+Doxygen::htmlFileExtension,
-                        hli==HLI_Directories,compact,relPath);
-    t << fixSpaces(theTranslator->trDirectories());
-    endQuickIndexItem(t);
-  } 
-
-  // -------------- Examples
-  
-  if (Doxygen::exampleSDict->count()>0)
-  {
-    startQuickIndexItem(t,"examples"+Doxygen::htmlFileExtension,
-                        hli==HLI_Examples,compact,relPath);
-    t << fixSpaces(theTranslator->trExamples());
-    endQuickIndexItem(t);
-  } 
-
-  // -------------- Search field
-
-  if (Config_getBool("SEARCHENGINE"))
-  {
-    QCString searchFor = fixSpaces(theTranslator->trSearchForIndex());
-    if (searchFor.at(0)=='S') searchFor="<u>S</u>"+searchFor.mid(1);
-    t << "    <li>\n";
-    t << "      <form action=\"" << relPath << "search.php\" method=\"get\">\n";
-    t << "        <table cellspacing=\"0\" cellpadding=\"0\" border=\"0\">\n";
-    t << "          <tr>\n";
-    t << "            <td><label>&nbsp;" << searchFor << "&nbsp;</label></td>\n";
-    if (hli!=HLI_Search)
-    {
-      t << "            <td><input type=\"text\" name=\"query\" value=\"\" size=\"20\" accesskey=\"s\"/></td>\n";
-      t << "          </tr>\n";
-      t << "        </table>\n";
-      t << "      </form>\n";
-      t << "    </li>\n";
-    }
-  } 
-  if (hli!=HLI_Search) // on the search page the page will be ended by the
-                       // page itself
-  {
-    endQuickIndexList(t,compact);
-  }
-
-  //-------------------------------------------------------------------------
-  // write sub indices in compact mode
-
-  if ((hli==HLI_Namespaces || hli==HLI_NamespaceMembers || 
-       hli==HLI_NamespaceVisible
-      ) && 
-      documentedNamespaces>0 &&
-      documentedNamespaceMembers[NMHL_All]>0)
-  {
-    writeNamespaceSubIndex(t,compact,hli,relPath);
-  }
-  else if ((hli==HLI_Hierarchy || hli==HLI_Classes || 
-            hli==HLI_Annotated || hli==HLI_Functions || 
-            hli==HLI_ClassVisible || !compact
-           ) && annotatedClasses>0
-          )
-  {
-    writeClassSubIndex(t,compact,hli,relPath);
-  }
-  else if ((hli==HLI_Files || hli==HLI_Globals || 
-            hli==HLI_FileVisible || !compact
-           ) && documentedHtmlFiles>0 && documentedFileMembers[FMHL_All]>0
-          )
-  {
-    writeFileSubIndex(t,compact,hli,relPath);
-  }
-  
-}
-#endif
-
 void HtmlGenerator::startQuickIndices()
 {
   if (!Config_getBool("DISABLE_INDEX"))
@@ -2345,6 +2025,7 @@ void HtmlGenerator::generateSectionImages()
     {
       f.writeBlock((char*)open_gif,open_gif_len);
     }
+    Doxygen::indexList.addImageFile("open.gif");
   }
   {
     QCString fileName = Config_getString("HTML_OUTPUT")+"/closed.gif";
@@ -2353,6 +2034,7 @@ void HtmlGenerator::generateSectionImages()
     {
       f.writeBlock((char*)closed_gif,closed_gif_len);
     }
+    Doxygen::indexList.addImageFile("closed.gif");
   }
 }
 
