@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * $Id: htmlhelp.cpp,v 1.8 2001/03/19 19:27:40 root Exp $
+ * 
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -22,12 +22,15 @@
 #include <stdlib.h>
 #include <qlist.h>
 #include <qdict.h>
+#include <qregexp.h>
+#include "qtextcodec.h"
 
 #include "htmlhelp.h"
 #include "config.h"
 #include "message.h"
 #include "doxygen.h"
 #include "language.h"
+#include "portable.h"
 
 //----------------------------------------------------------------------------
 
@@ -115,6 +118,10 @@ void HtmlHelpIndex::addItem(const char *level1,const char *level2,
 {
   QCString key = level1; 
   if (level2) key+= (QCString)"?" + level2;
+  if (key.find(QRegExp("@[0-9]+"))!=-1) // skip anonymous stuff
+  {
+    return;
+  }
   if (dict->find(key)==0) // new key
   {
     //printf(">>>>>>>>> HtmlHelpIndex::addItem(%s,%s,%s,%s)\n",
@@ -268,8 +275,13 @@ HtmlHelp::HtmlHelp() : indexFileDict(1009)
   dc = 0;
   cf = kf = 0;
   index = new HtmlHelpIndex;
+  m_fromUtf8 = (void *)(-1);
 }
 
+HtmlHelp::~HtmlHelp()
+{
+  if (m_fromUtf8!=(void *)(-1))   portable_iconv_close(m_fromUtf8);
+}
 #if 0
 /*! return a reference to the one and only instance of this class. 
  */
@@ -289,6 +301,10 @@ static QDict<QCString> s_languageDict;
  */
 void HtmlHelp::initialize()
 {
+  const char *str = Config_getString("CHM_INDEX_ENCODING");
+  if(!str) str = "Windows-1250";
+  m_fromUtf8 = portable_iconv_open(str,"UTF-8"); 
+
   /* open the contents file */
   QCString fName = Config_getString("HTML_OUTPUT") + "/index.hhc";
   cf = new QFile(fName);
@@ -299,9 +315,7 @@ void HtmlHelp::initialize()
   }
   /* Write the header of the contents file */
   cts.setDevice(cf);
-#if QT_VERSION >= 200
   cts.setEncoding(QTextStream::Latin1);
-#endif
   cts << "<!DOCTYPE HTML PUBLIC \"-//IETF//DTD HTML//EN\">\n"
          "<HTML><HEAD></HEAD><BODY>\n"
          "<OBJECT type=\"text/site properties\">\n"
@@ -319,9 +333,7 @@ void HtmlHelp::initialize()
   }
   /* Write the header of the contents file */
   kts.setDevice(kf);
-#if QT_VERSION >= 200
   kts.setEncoding(QTextStream::Latin1);
-#endif
   kts << "<!DOCTYPE HTML PUBLIC \"-//IETF//DTD HTML//EN\">\n"
          "<HTML><HEAD></HEAD><BODY>\n"
          "<OBJECT type=\"text/site properties\">\n"
@@ -360,6 +372,23 @@ void HtmlHelp::initialize()
      0x412 Korean
      0x804 Chinese (PRC)
      0x404 Chinese (Taiwan)
+
+     New LCIDs:
+	 0x421 Indonesian
+	 0x41A Croatian
+	 0x418 Romanian
+	 0x424 Slovenian
+	 0x41B Slovak
+	 0x422 Ukrainian
+	 0x81A Serbian (Serbia, Latin)
+	 0x403 Catalan
+	 0x427 Lithuanian
+	 0x436 Afrikaans
+	 0x42A Vietnamese
+	 0x429 Persian (Iran)
+	 0xC01 Arabic (Egypt) - I don't know which version of arabic is used inside translator_ar.h ,
+     so I have chosen Egypt at random
+
   */
   s_languageDict.setAutoDelete(TRUE);
   s_languageDict.clear();
@@ -369,22 +398,38 @@ void HtmlHelp::initialize()
   s_languageDict.insert("finnish",     new QCString("0x40B Finnish"));
   s_languageDict.insert("french",      new QCString("0x40C French"));
   s_languageDict.insert("german",      new QCString("0x407 German"));
-  s_languageDict.insert("greece",      new QCString("0x408 Greece"));
+  s_languageDict.insert("greek",       new QCString("0x408 Greece"));
   s_languageDict.insert("hungarian",   new QCString("0x40E Hungarian"));
   s_languageDict.insert("italian",     new QCString("0x410 Italian"));
   s_languageDict.insert("norwegian",   new QCString("0x814 Norwegian"));
   s_languageDict.insert("polish",      new QCString("0x415 Polish"));
-  s_languageDict.insert("portugese",   new QCString("0x816 Portuguese(Portugal)"));
+  s_languageDict.insert("portuguese",  new QCString("0x816 Portuguese(Portugal)"));
   s_languageDict.insert("brazil",      new QCString("0x416 Portuguese(Brazil)"));
   s_languageDict.insert("russian",     new QCString("0x419 Russian"));
-  s_languageDict.insert("spanish",     new QCString("0x40A Spannish(Traditional Sort)"));
+  s_languageDict.insert("spanish",     new QCString("0x40A Spanish(Traditional Sort)"));
   s_languageDict.insert("swedish",     new QCString("0x41D Swedish"));
-  s_languageDict.insert("turkey",      new QCString("0x41F Turkey"));
+  s_languageDict.insert("turkish",     new QCString("0x41F Turkey"));
   s_languageDict.insert("japanese",    new QCString("0x411 Japanese"));
   s_languageDict.insert("japanese-en", new QCString("0x411 Japanese"));
   s_languageDict.insert("korean",      new QCString("0x412 Korean"));
+  s_languageDict.insert("korean-en",   new QCString("0x412 Korean"));
   s_languageDict.insert("chinese",     new QCString("0x804 Chinese (PRC)"));
   s_languageDict.insert("chinese-traditional", new QCString("0x404 Chinese (Taiwan)"));
+
+  // new LCIDs
+  s_languageDict.insert("indonesian",  new QCString("0x412 Indonesian"));
+  s_languageDict.insert("croatian",    new QCString("0x41A Croatian"));
+  s_languageDict.insert("romanian",    new QCString("0x418 Romanian"));
+  s_languageDict.insert("slovene",     new QCString("0x424 Slovenian"));
+  s_languageDict.insert("slovak",      new QCString("0x41B Slovak"));
+  s_languageDict.insert("ukrainian",   new QCString("0x422 Ukrainian"));
+  s_languageDict.insert("serbian",     new QCString("0x81A Serbian (Serbia, Latin)"));
+  s_languageDict.insert("catalan",     new QCString("0x403 Catalan"));
+  s_languageDict.insert("lithuanian",  new QCString("0x427 Lithuanian"));
+  s_languageDict.insert("afrikaans",   new QCString("0x436 Afrikaans"));
+  s_languageDict.insert("vietnamese",  new QCString("0x42A Vietnamese"));
+  s_languageDict.insert("persian",     new QCString("0x429 Persian (Iran)"));
+  s_languageDict.insert("arabic",      new QCString("0xC01 Arabic (Egypt)"));
 }
 
 
@@ -419,7 +464,7 @@ void HtmlHelp::createProjectFile()
    
     
     QCString indexName="index"+Doxygen::htmlFileExtension;
-    if (Config_getBool("GENERATE_TREEVIEW")) indexName="main"+Doxygen::htmlFileExtension;
+    if (usingTreeIndex()) indexName="main"+Doxygen::htmlFileExtension;
     t << "[OPTIONS]\n";
     if (!Config_getString("CHM_FILE").isEmpty())
     {
@@ -434,12 +479,19 @@ void HtmlHelp::createProjectFile()
          "Language=" << getLanguageString() << endl;
     if (Config_getBool("BINARY_TOC")) t << "Binary TOC=YES\n";
     if (Config_getBool("GENERATE_CHI")) t << "Create CHI file=YES\n";
-    t << "Title=" << Config_getString("PROJECT_NAME") << endl << endl;
+    t << "Title=" << recode(Config_getString("PROJECT_NAME")) << endl << endl;
     
     t << "[WINDOWS]" << endl;
-    t << "main=\"" << Config_getString("PROJECT_NAME") << "\",\"index.hhc\","
+
+    // NOTE: the 0x10387e number is a set of bits specifying the buttons
+    //       which should appear in the CHM viewer; that specific value
+    //       means "show all buttons including the font-size one";
+    //       the font-size one is not normally settable by the HTML Help Workshop
+    //       utility but the way to set it is described here:
+    //          http://support.microsoft.com/?scid=kb%3Ben-us%3B240062&x=17&y=18
+    t << "main=\"" << recode(Config_getString("PROJECT_NAME")) << "\",\"index.hhc\","
          "\"index.hhk\",\"" << indexName << "\",\"" << 
-         indexName << "\",,,,,0x23520,,0x387e,,,,,,,,0" << endl << endl;
+         indexName << "\",,,,,0x23520,,0x10387e,,,,,,,,0" << endl << endl;
     
     t << "[FILES]" << endl;
     char *s = indexFiles.first();
@@ -524,6 +576,28 @@ void HtmlHelp::decContentsDepth()
   --dc;
 }
 
+QCString HtmlHelp::recode(const QCString &s) 
+{
+  int iSize        = s.length();
+  int oSize        = iSize*4+1;
+  QCString output(oSize);
+  size_t iLeft     = iSize;
+  size_t oLeft     = oSize;
+  const char *iPtr = s.data();
+  char *oPtr       = output.data();
+  if (!portable_iconv(m_fromUtf8,&iPtr,&iLeft,&oPtr,&oLeft))
+  {
+    oSize -= oLeft;
+    output.resize(oSize+1);
+    output.at(oSize)='\0';
+    return output;
+  }
+  else
+  {
+    return s;
+  }
+}
+
 /*! Add an list item to the contents file.
  *  \param isDir boolean indicating if this is a dir or file entry
  *  \param name the name of the item.
@@ -543,10 +617,9 @@ void HtmlHelp::addContentsItem(bool isDir,
     file = 0;
     anchor = 0;
   }
-  
   int i; for (i=0;i<dc;i++) cts << "  ";
   cts << "<LI><OBJECT type=\"text/sitemap\">";
-  cts << "<param name=\"Name\" value=\"" << name << "\">";
+  cts << "<param name=\"Name\" value=\"" << recode(name) << "\">";
   if (file)      // made file optional param - KPW
   {
     cts << "<param name=\"Local\" value=\"" << file << Doxygen::htmlFileExtension;
@@ -572,12 +645,14 @@ void HtmlHelp::addContentsItem(bool isDir,
  *  \param contRef the output file refering to the container.
  *  \param memRef  the output file containing to the member documentation.
  *  \param anchor  the anchor of the item.
+ *  \param md      the member definition corresponding to this item.
  *  \sa HtmlHelpIndex
  */
 void HtmlHelp::addIndexItem(const char *level1, const char *level2,
                             const char *contRef, const char *memRef, 
-                            const char *anchor)
+                            const char *anchor,const MemberDef *md)
 {
+  (void)md;
   index->addItem(level1,level2,contRef,anchor,TRUE,FALSE);
   index->addItem(level2,level1,memRef,anchor,TRUE,TRUE);
 }
