@@ -2,7 +2,7 @@
  *
  * $Id: latexgen.cpp,v 1.58 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -64,6 +64,7 @@ LatexGenerator::LatexGenerator() : OutputGenerator()
   disableLinks=FALSE;
   m_indent=0;
   templateMemberItem = FALSE;
+  m_prettyCode=Config_getBool("LATEX_SOURCE_CODE");
 }
 
 LatexGenerator::~LatexGenerator()
@@ -187,6 +188,8 @@ static void writeDefaultHeaderPart1(QTextStream &t)
     "\\usepackage{graphicx}\n"
     "\\usepackage{multicol}\n"
     "\\usepackage{float}\n"
+    "\\usepackage{listings}\n"
+    "\\usepackage{color}\n"
     "\\usepackage{textcomp}\n"
     "\\usepackage{alltt}\n"
     //"\\usepackage{ae,aecompl,aeguill}\n"
@@ -228,6 +231,16 @@ static void writeDefaultHeaderPart1(QTextStream &t)
     t << sLanguageSupportCommand << endl;
   }
   t << "\\usepackage{doxygen}\n";
+
+  // define option for listings
+  t << "\\lstset{language=C++,"
+                "inputencoding=utf8,"
+                "basicstyle=\\footnotesize,"
+                "breaklines=true,"
+                "breakatwhitespace=true,"
+                "tabsize=" << Config_getInt("TAB_SIZE") <<","
+                "numbers=left }" << endl;
+
   QStrList &extraPackages = Config_getList("EXTRA_PACKAGES");
   const char *s=extraPackages.first();
   while (s)
@@ -236,14 +249,23 @@ static void writeDefaultHeaderPart1(QTextStream &t)
     s=extraPackages.next();
   }
   t << "\\makeindex\n"
-    "\\setcounter{tocdepth}{1}\n"
+    "\\setcounter{tocdepth}{3}\n"
     "\\renewcommand{\\footrulewidth}{0.4pt}\n"
     "\\begin{document}\n";
+  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
+  static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
+  if (pdfHyperlinks && usePDFLatex)
+  {
+    // to avoid duplicate page anchors due to reuse of same numbers for
+    // the index (be it as roman numbers)
+    t << "\\hypersetup{pageanchor=false}" << endl;
+  }
   if (theTranslator->idLanguage()=="greek") t << "\\selectlanguage{greek}\n";
   t << "\\begin{titlepage}\n"
     "\\vspace*{7cm}\n"
     "\\begin{center}\n"
     "{\\Large ";
+
 }
 
 static void writeDefaultHeaderPart2(QTextStream &t)
@@ -267,6 +289,12 @@ static void writeDefaultHeaderPart3(QTextStream &t)
   t << "\\tableofcontents\n";
   if (!Config_getBool("COMPACT_LATEX")) t << "\\clearemptydoublepage\n";
   t << "\\pagenumbering{arabic}\n";
+  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
+  static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
+  if (pdfHyperlinks && usePDFLatex)
+  {
+    t << "\\hypersetup{pageanchor=true}" << endl;
+  }
 }
 
 static void writeDefaultStyleSheetPart1(QTextStream &t)
@@ -276,6 +304,7 @@ static void writeDefaultStyleSheetPart1(QTextStream &t)
   t << "\\ProvidesPackage{doxygen}\n";
   t << "\\RequirePackage{calc}\n";
   t << "\\RequirePackage{array}\n";
+  t << "\\RequirePackage{color}\n";
   t << "\\pagestyle{fancyplain}\n";
   //t << "\\addtolength{\\headwidth}{\\marginparsep}\n";
   //t << "\\addtolength{\\headwidth}{\\marginparwidth}\n";
@@ -365,6 +394,24 @@ static void writeDefaultStyleSheetPart3(QTextStream &t)
   t << "\\addtocounter{secnumdepth}{1}\n";
   t << "\\sloppy\n";
   t << "\\usepackage[T1]{fontenc}\n";
+  t << "\\makeatletter\n";
+  t << "\\renewcommand{\\paragraph}{\\@startsection{paragraph}{4}{0ex}%\n";
+  t << "   {-3.25ex plus -1ex minus -0.2ex}%\n";
+  t << "   {1.5ex plus 0.2ex}%\n";
+  t << "   {\\normalfont\\normalsize\\bfseries}}\n";
+  t << "\\makeatother\n";
+  t << "\\stepcounter{secnumdepth}\n";
+  t << "\\stepcounter{tocdepth}\n";
+  t << "\\definecolor{comment}{rgb}{0.5,0.0,0.0}\n";
+  t << "\\definecolor{keyword}{rgb}{0.0,0.5,0.0}\n";
+  t << "\\definecolor{keywordtype}{rgb}{0.38,0.25,0.125}\n";
+  t << "\\definecolor{keywordflow}{rgb}{0.88,0.5,0.0}\n";
+  t << "\\definecolor{preprocessor}{rgb}{0.5,0.38,0.125}\n";
+  t << "\\definecolor{stringliteral}{rgb}{0.0,0.125,0.25}\n";
+  t << "\\definecolor{charliteral}{rgb}{0.0,0.5,0.5}\n";
+  t << "\\definecolor{vhdldigit}{rgb}{1.0,0.0,1.0}\n";
+  t << "\\definecolor{vhdlkeyword}{rgb}{0.43,0.0,0.43}\n";
+  t << "\\definecolor{vhdllogic}{rgb}{1.0,0.0,0.0}\n";
 }
 
 void LatexGenerator::writeHeaderFile(QFile &f)
@@ -380,9 +427,7 @@ void LatexGenerator::writeHeaderFile(QFile &f)
 void LatexGenerator::writeStyleSheetFile(QFile &f)
 {
   QTextStream t(&f);
-#if QT_VERSION >= 200
-  t.setEncoding(QTextStream::Latin1);
-#endif
+  t.setEncoding(QTextStream::UnicodeUTF8);
 
   writeDefaultStyleSheetPart1(t);
   QCString &projectName = Config_getString("PROJECT_NAME");
@@ -390,12 +435,12 @@ void LatexGenerator::writeStyleSheetFile(QFile &f)
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2007";
+  //t << "Dimitri van Heesch \\copyright~1997-2008";
   writeDefaultStyleSheetPart2(t);
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2007";
+  //t << "Dimitri van Heesch \\copyright~1997-2008";
   writeDefaultStyleSheetPart3(t);
 }
 
@@ -406,6 +451,7 @@ void LatexGenerator::startFile(const char *name,const char *,const char *)
 #endif
   QCString fileName=name;
   relPath = relativePathToRoot(fileName);
+  sourceFileName = stripPath(fileName);
   if (fileName.right(4)!=".tex" && fileName.right(4)!=".sty") fileName+=".tex";
   startPlainFile(fileName);
 }
@@ -413,6 +459,7 @@ void LatexGenerator::startFile(const char *name,const char *,const char *)
 void LatexGenerator::endFile()
 {
   endPlainFile();
+  sourceFileName.resize(0);
 }
 
 //void LatexGenerator::writeIndex()
@@ -587,6 +634,8 @@ void LatexGenerator::startIndexSection(IndexSections is)
         t << "{"; //Page Documentation}\n";
       }
       break;
+    case isPageDocumentation2:
+      break;
     case isEndIndex:
       break;
   }
@@ -594,8 +643,9 @@ void LatexGenerator::startIndexSection(IndexSections is)
 
 void LatexGenerator::endIndexSection(IndexSections is)
 {
-  bool &compactLatex = Config_getBool("COMPACT_LATEX");
-  QCString &latexHeader = Config_getString("LATEX_HEADER");
+  static bool compactLatex = Config_getBool("COMPACT_LATEX");
+  static bool sourceBrowser = Config_getBool("SOURCE_BROWSER");
+  static QCString latexHeader = Config_getString("LATEX_HEADER");
   switch (is)
   {
     case isTitlePageStart:
@@ -608,8 +658,7 @@ void LatexGenerator::endIndexSection(IndexSections is)
       break;
     case isMainPage:
       {
-        QCString indexName="index";
-        if (Config_getBool("GENERATE_TREEVIEW")) indexName="main";
+        QCString indexName=usingTreeIndex()?"main":"index";
         t << "}\n\\label{index}";
         if (Config_getBool("PDF_HYPERLINKS")) t << "\\hypertarget{index}{}";
         t << "\\input{" << indexName << "}\n";
@@ -743,12 +792,21 @@ void LatexGenerator::endIndexSection(IndexSections is)
               if (isFirst)
               {
                 t << "}\n\\input{" << fd->getOutputFileBase() << "}\n";
+                if (sourceBrowser && m_prettyCode)
+                {
+                  t << "\\input{" << fd->getSourceFileBase() << "}\n";
+                }
                 isFirst=FALSE;
               }
               else
               {
                 if (compactLatex) t << "\\input" ; else t << "\\include";
                 t << "{" << fd->getOutputFileBase() << "}\n";
+                if (sourceBrowser && m_prettyCode)
+                {
+                  if (compactLatex) t << "\\input" ; else t << "\\include";
+                  t << "{" << fd->getSourceFileBase() << "}\n";
+                }
               }
             }
             fd=fn->next();
@@ -776,6 +834,7 @@ void LatexGenerator::endIndexSection(IndexSections is)
     case isPageDocumentation:
       {
         t << "}\n";
+#if 0
         PageSDict::Iterator pdi(*Doxygen::pageSDict);
         PageDef *pd=pdi.toFirst();
         bool first=TRUE;
@@ -783,19 +842,35 @@ void LatexGenerator::endIndexSection(IndexSections is)
         {
           if (!pd->getGroupDef() && !pd->isReference())
           {
+             if (compactLatex) t << "\\section"; else t << "\\chapter";
+             t << "{" << pd->title();
+             t << "}\n";
+            
             if (compactLatex || first) t << "\\input" ; else t << "\\include";
             t << "{" << pd->getOutputFileBase() << "}\n";
             first=FALSE;
           }
         }
+#endif
       }
       break;
+    case isPageDocumentation2:
+      break;
     case isEndIndex:
       t << "\\printindex\n";
       t << "\\end{document}\n";
       break;
   }
 }
+
+void LatexGenerator::writePageLink(const char *name, bool first)
+{
+  bool &compactLatex = Config_getBool("COMPACT_LATEX");
+  if (compactLatex || first) t << "\\input" ; else t << "\\include";
+  t << "{" << name << "}\n";
+}
+
+
 void LatexGenerator::writeStyleInfo(int part)
 {
   switch(part)
@@ -813,14 +888,14 @@ void LatexGenerator::writeStyleInfo(int part)
       break;
     case 2:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2007";
+        //t << " Dimitri van Heesch \\copyright~1997-2008";
         t << "}]{}\n";
         writeDefaultStyleSheetPart2(t);
       }
       break;
     case 4:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2007";
+        //t << " Dimitri van Heesch \\copyright~1997-2008";
         writeDefaultStyleSheetPart3(t);
         endPlainFile();
       }
@@ -998,17 +1073,38 @@ void LatexGenerator::endPageRef(const char *clname, const char *anchor)
   t << "}";
 }
 
-void LatexGenerator::writeCodeLink(const char *,const char *,
-                                   const char *,const char *name,
+void LatexGenerator::writeCodeLink(const char *ref,const char *f,
+                                   const char *anchor,const char *name,
                                    const char *)
 {
-  t << name;
-  col+=strlen(name);
+  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
+  static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
+  int l = strlen(name);
+  if (col+l>80)
+  {
+    t << "\n      ";
+    col=0;
+  }
+  if (m_prettyCode && !disableLinks && !ref && usePDFLatex && pdfHyperlinks)
+  {
+    t << "\\hyperlink{";
+    if (f) t << stripPath(f);
+    if (f && anchor) t << "_"; 
+    if (anchor) t << anchor; 
+    t << "}{" << name << "}";
+  }
+  else
+  {
+    t << name;
+  }
+  col+=l;
 }
 
 void LatexGenerator::startTitleHead(const char *fileName)
 {
-  if (Config_getBool("PDF_HYPERLINKS") && fileName)
+  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
+  static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
+  if (usePDFLatex && pdfHyperlinks && fileName)
   {
     t << "\\hypertarget{" << stripPath(fileName) << "}{" << endl;
   }
@@ -1024,6 +1120,8 @@ void LatexGenerator::startTitleHead(const char *fileName)
 
 void LatexGenerator::endTitleHead(const char *fileName,const char *name)
 {
+  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
+  static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
   t << "}" << endl;
   if (name)
   {
@@ -1033,7 +1131,7 @@ void LatexGenerator::endTitleHead(const char *fileName,const char *name)
     escapeMakeIndexChars(name);
     t << "}}" << endl;
   }
-  if (Config_getBool("PDF_HYPERLINKS") && fileName)
+  if (usePDFLatex && pdfHyperlinks && fileName)
   {
     t << "}" << endl;
   }
@@ -1092,7 +1190,7 @@ void LatexGenerator::endMemberHeader()
 void LatexGenerator::startMemberDoc(const char *clname,
                                     const char *memname,
                                     const char *,
-                                    const char *)
+                                    const char *title)
 { 
   if (memname && memname[0]!='@')
   {
@@ -1129,6 +1227,9 @@ void LatexGenerator::startMemberDoc(const char *clname,
   //  escapeMakeIndexChars(this,t,memname);
   //  t << "]";
   //}
+  t << "[{";
+  escapeMakeIndexChars(title);
+  t << "}]";
   t << "{\\setlength{\\rightskip}{0pt plus 5cm}";
   disableLinks=TRUE;
 }
@@ -1144,7 +1245,9 @@ void LatexGenerator::startDoxyAnchor(const char *fName,const char *,
                                      const char *anchor, const char *,
                                      const char *)
 {
-  if (Config_getBool("PDF_HYPERLINKS"))
+  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
+  static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
+  if (usePDFLatex && pdfHyperlinks)
   {
     t << "\\hypertarget{";
     if (fName) t << stripPath(fName);
@@ -1155,7 +1258,9 @@ void LatexGenerator::startDoxyAnchor(const char *fName,const char *,
 
 void LatexGenerator::endDoxyAnchor(const char *fName,const char *anchor)
 {
-  if (Config_getBool("PDF_HYPERLINKS"))
+  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
+  static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
+  if (usePDFLatex && pdfHyperlinks)
   {
     t << "}" << endl;
   }
@@ -1169,9 +1274,18 @@ void LatexGenerator::writeAnchor(const char *fName,const char *name)
 { 
   //printf("LatexGenerator::writeAnchor(%s,%s)\n",fName,name);
   t << "\\label{" << name << "}" << endl; 
-  if (fName && Config_getBool("PDF_HYPERLINKS"))
+  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
+  static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
+  if (usePDFLatex && pdfHyperlinks)
   {
-    t << "\\hypertarget{" << stripPath(fName) << "_" << name << "}{}" << endl;
+    if (fName)
+    {
+      t << "\\hypertarget{" << stripPath(fName) << "_" << name << "}{}" << endl;
+    }
+    else
+    {
+      t << "\\hypertarget{" << name << "}{}" << endl;
+    }
   }
 }
 
@@ -1205,7 +1319,9 @@ void LatexGenerator::addIndexItem(const char *s1,const char *s2)
 
 void LatexGenerator::startSection(const char *lab,const char *,SectionInfo::SectionType type)
 {
-  if (Config_getBool("PDF_HYPERLINKS"))
+  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
+  static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
+  if (usePDFLatex && pdfHyperlinks)
   {
     t << "\\hypertarget{" << stripPath(lab) << "}{}";
   }
@@ -1259,8 +1375,10 @@ void LatexGenerator::codify(const char *str)
   { 
     const char *p=str;
     char c;
+    char cs[2];
+    cs[1]='\0';
     int spacesToNextTabStop;
-    int &tabSize = Config_getInt("TAB_SIZE");
+    static int tabSize = Config_getInt("TAB_SIZE");
     while (*p)
     {
       static bool MultiByte = FALSE;
@@ -1287,11 +1405,29 @@ void LatexGenerator::codify(const char *str)
         case 0x0c: break; // remove ^L
         case '\t': spacesToNextTabStop =
                          tabSize - (col%tabSize);
-                   t << spaces.left(spacesToNextTabStop); 
+                   t << Doxygen::spaces.left(spacesToNextTabStop); 
                    col+=spacesToNextTabStop;
                    break; 
         case '\n': t << '\n'; col=0;                    break;
-        default:   t << c;    col++;                    break;
+        default:   if (m_prettyCode)
+                   {
+                     cs[0]=c; 
+                     filterLatexString(t,cs,insideTabbing,TRUE);
+                   }
+                   else
+                   {
+                     t << c;
+                   }
+                   if (col>=80)
+                   {
+                     t << "\n      ";
+                     col=0;
+                   }
+                   else
+                   {
+                     col++;                    
+                   }
+                   break;
       }
     }
   }
@@ -1568,6 +1704,13 @@ void LatexGenerator::endParamList()
   t << "\\end{Desc}" << endl;
 }
 
+void LatexGenerator::startParameterType(bool first,const char *key)
+{
+  if (!first)
+  {
+    t << "\\/ " << key << " ";
+  }
+}
 
 void LatexGenerator::printDoc(DocNode *n,const char *langExt)
 {
@@ -1628,8 +1771,8 @@ void LatexGenerator::escapeLabelName(const char *s)
     switch (c)
     {
       case '%': t << "\\%";       break;
-      case '|': t << "\\tt{\"|}"; break;
-      case '!': t << "\"!";       break;
+      //case '|': t << "\\tt{\"|}"; break;
+      //case '!': t << "\"!";       break;
       default:  str[0]=c; docify(str); break;
     }
   }
@@ -1645,10 +1788,10 @@ void LatexGenerator::escapeMakeIndexChars(const char *s)
   {
     switch (c)
     {
-      case '!': t << "\"!"; break;
+      //case '!': t << "\"!"; break;
       case '"': t << "\"\""; break;
       case '@': t << "\"@"; break;
-      case '|': t << "\\tt{\"|}"; break;
+      //case '|': t << "\\tt{\"|}"; break;
       case '[': t << "["; break;
       case ']': t << "]"; break;
       default:  str[0]=c; docify(str); break;
@@ -1656,4 +1799,93 @@ void LatexGenerator::escapeMakeIndexChars(const char *s)
   }
 }
 
+void LatexGenerator::startCodeFragment()
+{
+  if (m_prettyCode)
+  {
+    t << endl << endl;
+    t << "\\begin{footnotesize}\\begin{alltt}\n";
+  }
+  else
+  {
+    t << endl << endl << "\\begin{Code}\\begin{verbatim}";
+  }
+}
+
+void LatexGenerator::endCodeFragment()
+{
+  if (m_prettyCode)
+  {
+    t << "\\end{alltt}\\end{footnotesize}" << endl; 
+  }
+  else
+  {
+    t << "\\end{verbatim}\n\\end{Code}" << endl;
+  }
+}
+
+void LatexGenerator::writeLineNumber(const char *ref,const char *fileName,const char *anchor,int l)
+{
+  if (m_prettyCode)
+  {
+    QCString lineNumber;
+    lineNumber.sprintf("%05d",l);
+
+    if (fileName && !sourceFileName.isEmpty())
+    {
+      QCString lineAnchor;
+      lineAnchor.sprintf("_l%05d",l);
+      lineAnchor.prepend(sourceFileName);
+      startCodeAnchor(lineAnchor);
+      writeCodeLink(ref,fileName,anchor,lineNumber,0);
+      endCodeAnchor();
+    }
+    else
+    { 
+      codify(lineNumber);
+    }
+    t << " ";
+  }
+  else
+  {
+    t << l << " ";
+  }
+}
+
+void LatexGenerator::startCodeLine()
+{
+  col=0;
+}
+
+void LatexGenerator::endCodeLine()
+{
+  codify("\n");
+}
+
+void LatexGenerator::startFontClass(const char *name)
+{
+  if (!m_prettyCode) return;
+  t << "\\textcolor{" << name << "}{";
+}
+
+void LatexGenerator::endFontClass()
+{
+  if (!m_prettyCode) return;
+  t << "}";
+}
+
+void LatexGenerator::startCodeAnchor(const char *name) 
+{
+  static bool usePDFLatex = Config_getBool("USE_PDFLATEX");
+  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
+  if (!m_prettyCode) return;
+  if (usePDFLatex && pdfHyperlinks)
+  {
+    t << "\\hypertarget{" << stripPath(name) << "}{}";
+  }
+}
+
+void LatexGenerator::endCodeAnchor() 
+{
+}
 
