@@ -2,7 +2,7 @@
  *
  * $Id: latexgen.h,v 1.50 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -52,6 +52,7 @@ class LatexGenerator : public OutputGenerator
     
     void startIndexSection(IndexSections);
     void endIndexSection(IndexSections);
+    void writePageLink(const char *,bool);
     void startProjectNumber();
     void endProjectNumber() {}
     void writeStyleInfo(int part);
@@ -117,13 +118,13 @@ class LatexGenerator : public OutputGenerator
     
     void insertMemberAlign(bool) {}
 
-    void writeRuler() { t << endl << endl; /*t << "\\vspace{0.4cm}\\hrule\\vspace{0.2cm}" << endl; */ }
+    void writeRuler() { t << endl << endl; }
     void writeAnchor(const char *fileName,const char *name);
-    void startCodeFragment() { t << endl << endl << "\\begin{Code}\\begin{verbatim}"; }
-    void endCodeFragment()   { t << "\\end{verbatim}\n\\end{Code}" << endl; }
-    void writeLineNumber(const char *,const char *,const char *,int l) { t << l << " "; }
-    void startCodeLine() { col=0; }
-    void endCodeLine() { codify("\n"); }
+    void startCodeFragment();
+    void endCodeFragment();
+    void writeLineNumber(const char *,const char *,const char *,int l);
+    void startCodeLine();
+    void endCodeLine();
     void startEmphasis() { t << "{\\em ";  }
     void endEmphasis()   { t << "}"; }
     void startBold()     { t << "\\textbf{"; }
@@ -132,13 +133,13 @@ class LatexGenerator : public OutputGenerator
     void endDescription();
     void startDescItem();
     void endDescItem();
-    void lineBreak() { t << "\\par\n"; }
+    void lineBreak(const char *style=0) { (void)style; t << "\\par\n"; }
     void startMemberDoc(const char *,const char *,const char *,const char *);
     void endMemberDoc(bool);
     void startDoxyAnchor(const char *,const char *,const char *,const char *,const char *);
     void endDoxyAnchor(const char *,const char *);
-    void startCodeAnchor(const char *) {}
-    void endCodeAnchor() {}
+    void startCodeAnchor(const char *);
+    void endCodeAnchor();
     void writeChar(char c);
     void writeLatexSpacing() { t << "\\hspace{0.3cm}"; }
     void writeStartAnnoItem(const char *type,const char *file, 
@@ -171,7 +172,11 @@ class LatexGenerator : public OutputGenerator
     void endClassDiagram(const ClassDiagram &,const char *,const char *);
     void startPageRef();
     void endPageRef(const char *,const char *);
+    void startQuickIndices() {}
+    void endQuickIndices() {}
     void writeQuickLinks(bool,HighlightedItem) {}
+    void startContents() {}
+    void endContents() {}
     void writeNonBreakableSpace(int);
     
     void startDescTable()
@@ -205,7 +210,7 @@ class LatexGenerator : public OutputGenerator
     void endMemberDocPrefixItem() {}
     void startMemberDocName(bool) {}
     void endMemberDocName() {}
-    void startParameterType(bool,const char *) {}
+    void startParameterType(bool,const char *);
     void endParameterType() {}
     void startParameterName(bool) {}
     void endParameterName(bool,bool,bool) {}
@@ -221,8 +226,8 @@ class LatexGenerator : public OutputGenerator
     void endConstraintDocs();
     void endConstraintList();
 
-    void startFontClass(const char *) {}
-    void endFontClass() {}
+    void startFontClass(const char *); // {}
+    void endFontClass(); // {}
 
     void writeCodeAnchor(const char *) {}
     void linkableSymbol(int,const char *,Definition *,Definition *) {}
@@ -237,8 +242,10 @@ class LatexGenerator : public OutputGenerator
     bool firstDescItem;
     bool disableLinks;
     QCString relPath;
+    QCString sourceFileName;
     int m_indent;
     bool templateMemberItem;
+    bool m_prettyCode;
 };
 
 #endif
