@@ -2,7 +2,7 @@
  *
  * $Id: memberlist.cpp,v 1.35 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -25,13 +25,20 @@
 #include "doxygen.h"
 #include "outputlist.h"
 #include "groupdef.h"
+#include "marshal.h"
+#include "vhdldocgen.h"
 
-MemberList::MemberList() : QList<MemberDef>()
+MemberList::MemberList()
+{
+}
+
+MemberList::MemberList(ListType lt) : m_listType(lt)
 {
   memberGroupList=0;
-  m_numDecMembers=-1; // special value indicating that computation is needed
-  m_numDocMembers=-1; // special value indicating that computation is needed
+  m_numDecMembers=-1; // special value indicating that value needs to be computed
+  m_numDocMembers=-1; // special value indicating that value needs to be computed
   m_inGroup=FALSE;
+  m_inFile=FALSE;
 }
 
 MemberList::~MemberList()
@@ -49,7 +56,7 @@ int MemberList::compareItems(GCI item1, GCI item2)
 /*! Count the number of members in this list that are visible in
  *  the declaration part of a compound's documentation page.
  */
-void MemberList::countDecMembers()
+void MemberList::countDecMembers(bool countEnumValues)
 {
   if (m_numDecMembers!=-1) return; 
   
@@ -61,6 +68,7 @@ void MemberList::countDecMembers()
   MemberDef *md;
   for (mli.toFirst();(md=mli.current());++mli)
   {
+    //printf("MemberList::countDecMembers(md=%s,%d)\n",md->name().data(),md->isBriefSectionVisible());
     if (md->isBriefSectionVisible())
     {
       switch(md->memberType())
@@ -76,10 +84,11 @@ void MemberList::countDecMembers()
                                        m_funcCnt++,m_numDecMembers++; 
                                      break;
         case MemberDef::Enumeration: m_enumCnt++,m_numDecMembers++; break;
-        case MemberDef::EnumValue:   //m_enumValCnt++,m_numDecMembers++; 
+        case MemberDef::EnumValue:   if (countEnumValues)
+                                       m_enumValCnt++,m_numDecMembers++; 
                                      break;
         case MemberDef::Typedef:     m_typeCnt++,m_numDecMembers++; break;
-        case MemberDef::Prototype:   m_protoCnt++,m_numDecMembers++; break;
+        //case MemberDef::Prototype:   m_protoCnt++,m_numDecMembers++; break;
         case MemberDef::Define:      if (Config_getBool("EXTRACT_ALL") || 
                                          md->argsString() || 
                                          !md->initializer().isEmpty() ||
@@ -116,7 +125,7 @@ void MemberList::countDecMembers()
   //printf("MemberList::countDecMembers()=%d\n",m_numDecMembers);
 }
 
-void MemberList::countDocMembers()
+void MemberList::countDocMembers(bool countEnumValues)
 {
   if (m_numDocMembers!=-1) return; // used cached value
   m_numDocMembers=0;
@@ -124,10 +133,11 @@ void MemberList::countDocMembers()
   MemberDef *md;
   for (mli.toFirst();(md=mli.current());++mli)
   {
-    if (md->isDetailedSectionVisible(m_inGroup)) 
+    if (md->isDetailedSectionVisible(m_inGroup,m_inFile)) 
     {
       // do not count enum values, since they do not produce entries of their own
-      if (md->memberType()!=MemberDef::EnumValue) m_numDocMembers++;
+      if (countEnumValues || md->memberType()!=MemberDef::EnumValue) 
+        m_numDocMembers++;
     }
   }
   if (memberGroupList)
@@ -136,7 +146,7 @@ void MemberList::countDocMembers()
     MemberGroup *mg;
     for (;(mg=mgli.current());++mgli)
     {
-      mg->countDecMembers();
+      mg->countDocMembers();
       m_numDocMembers+=mg->numDocMembers();
     }
   }
@@ -169,8 +179,12 @@ void MemberList::writePlainDeclarations(OutputList &ol,
 {
   //printf("----- writePlainDeclaration() ----\n");
   countDecMembers();
-  if (numDecMembers()==0) return; // no members in this list
-  //printf("----> writePlainDeclaration() numDecMembers()=%d\n",
+  if (numDecMembers()==0) 
+  {
+    //printf("  --> no members!\n");
+    return; // no members in this list
+  }
+  //printf("  --> writePlainDeclaration() numDecMembers()=%d\n",
   //     numDecMembers());
   
   ol.pushGeneratorState();
@@ -180,13 +194,14 @@ void MemberList::writePlainDeclarations(OutputList &ol,
   MemberListIterator mli(*this);
   for ( ; (md=mli.current()); ++mli )
   {
+    //printf(">>> Member `%s' type=%d visible=%d\n",
+    //    md->name().data(),md->memberType(),md->isBriefSectionVisible());
     if (md->isBriefSectionVisible())
     {
-      //printf(">>> Member `%s' type=%d\n",md->name().data(),md->memberType());
       switch(md->memberType())
       {
         case MemberDef::Define:    // fall through
-        case MemberDef::Prototype: // fall through
+        //case MemberDef::Prototype: // fall through
         case MemberDef::Typedef:   // fall through
         case MemberDef::Variable:  // fall through
         case MemberDef::Function:  // fall through
@@ -202,7 +217,6 @@ void MemberList::writePlainDeclarations(OutputList &ol,
           }
         case MemberDef::Enumeration: 
           {
-            if (first) ol.startMemberList(),first=FALSE;
             int enumVars=0;
             MemberListIterator vmli(*this);
             MemberDef *vmd;
@@ -225,6 +239,8 @@ void MemberList::writePlainDeclarations(OutputList &ol,
             // enum type (i.e. enumVars>0), then we do not show the enum here.
             if (enumVars==0) // show enum here
             {
+              //printf("Enum!!\n");
+              if (first) ol.startMemberList(),first=FALSE;
               ol.startMemberItem(0);
               ol.writeString("enum ");
               ol.insertMemberAlign();
@@ -263,6 +279,14 @@ void MemberList::writePlainDeclarations(OutputList &ol,
             break;
           }
         case MemberDef::EnumValue: 
+          {
+            if (m_inGroup)
+            {
+              //printf("EnumValue!\n");
+              if (first) ol.startMemberList(),first=FALSE;
+              md->writeDeclaration(ol,cd,nd,fd,gd,m_inGroup);
+            }
+          }
           break;
       }
     }
@@ -297,13 +321,21 @@ void MemberList::writePlainDeclarations(OutputList &ol,
 
 void MemberList::writeDeclarations(OutputList &ol,
              ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd,
-             const char *title,const char *subtitle
+             const char *title,const char *subtitle, bool showEnumValues
              /*, bool inGroup,bool countSubGroups*/)
 {
-  //printf("----- writeDeclaration() ----\n");
-  countDecMembers(); // count member not in group
+  //printf("----- writeDeclaration() this=%p ----\n",this);
+  static bool optimizeVhdl = Config_getBool("OPTIMIZE_OUTPUT_VHDL");
+
+  countDecMembers(showEnumValues); // count member not in group
+  Definition *ctx = cd;
+  if (ctx==0 && nd) ctx = nd;
+  if (ctx==0 && gd) ctx = gd;
+  if (ctx==0 && fd) ctx = fd;
+
   if (numDecMembers()==0) return;
-  //printf("MemberList::writeDeclaration(title=`%s',subtitle=`%s')=%d\n",title,subtitle,numDecMembers());
+  //printf("%p: MemberList::writeDeclaration(title=`%s',subtitle=`%s')=%d\n",
+  //    this,title,subtitle,numDecMembers());
   if (title) 
   {
     ol.startMemberHeader();
@@ -314,12 +346,25 @@ void MemberList::writeDeclarations(OutputList &ol,
   {
     //printf("subtitle=`%s'\n",subtitle);
     ol.startMemberSubtitle();
-    ol.parseDoc("<generated>",-1,0,0,subtitle,FALSE,FALSE);
+    ol.parseDoc("[generated]",-1,ctx,0,subtitle,FALSE,FALSE);
     ol.endMemberSubtitle();
   }
 
-  writePlainDeclarations(ol,cd,nd,fd,gd);
-  
+  // TODO: Two things need to be worked out for proper VHDL output:
+  // 1. Signals and types under the group need to be
+  //    formatted to associate them with the group somehow
+  //    indentation, or at the very least, extra space after
+  //    the group is done
+  // 2. This might need to be repeated below for memberGroupLists
+  if (optimizeVhdl) // use specific declarations function
+  {
+    VhdlDocGen::writeVhdlDeclarations(this,ol,0,cd,0);
+  }
+  else
+  {
+    writePlainDeclarations(ol,cd,nd,fd,gd);
+  }
+ 
   //printf("memberGroupList=%p\n",memberGroupList);
   if (memberGroupList)
   {
@@ -327,6 +372,7 @@ void MemberList::writeDeclarations(OutputList &ol,
     MemberGroup *mg;
     while ((mg=mgli.current()))
     {
+      //printf("mg->header=%s\n",mg->header().data());
       bool hasHeader=mg->header()!="[NOHEADER]";
       ol.startMemberGroupHeader(hasHeader);
       if (hasHeader)
@@ -338,7 +384,7 @@ void MemberList::writeDeclarations(OutputList &ol,
       {
         //printf("Member group has docs!\n");
         ol.startMemberGroupDocs();
-        ol.parseDoc("<generated>",-1,0,0,mg->documentation()+"\n",FALSE,FALSE);
+        ol.parseDoc("[generated]",-1,ctx,0,mg->documentation()+"\n",FALSE,FALSE);
         ol.endMemberGroupDocs();
       }
       ol.startMemberGroup();
@@ -354,11 +400,11 @@ void MemberList::writeDeclarations(OutputList &ol,
 
 void MemberList::writeDocumentation(OutputList &ol,
                      const char *scopeName, Definition *container,
-                     const char *title)
+                     const char *title,bool showEnumValues)
 {
   //printf("MemberList::writeDocumentation()\n");
 
-  countDocMembers();
+  countDocMembers(showEnumValues);
   if (numDocMembers()==0) return;
 
   if (title)
@@ -368,12 +414,13 @@ void MemberList::writeDocumentation(OutputList &ol,
     ol.parseText(title);
     ol.endGroupHeader();
   }
+  ol.startMemberDocList();
   
   MemberListIterator mli(*this);
   MemberDef *md;
   for ( ; (md=mli.current()) ; ++mli)
   {
-    md->writeDocumentation(this,ol,scopeName,container,m_inGroup);
+    md->writeDocumentation(this,ol,scopeName,container,m_inGroup,showEnumValues);
   }
   if (memberGroupList)
   {
@@ -385,6 +432,48 @@ void MemberList::writeDocumentation(OutputList &ol,
       mg->writeDocumentation(ol,scopeName,container);
     }
   }
+  ol.endMemberDocList();
+}
+
+void MemberList::writeDocumentationPage(OutputList &ol,
+                     const char *scopeName, Definition *container)
+{
+  MemberListIterator mli(*this);
+  MemberDef *md;
+  for ( ; (md=mli.current()) ; ++mli)
+  {
+    QCString diskName=md->getOutputFileBase();
+    QCString title=md->qualifiedName();
+    startFile(ol,diskName,md->name(),title);
+    container->writeNavigationPath(ol);
+
+    ol.writeString("<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\">\n"
+                   "  <tr>\n"
+                   "   <td valign=\"top\">\n");
+
+    container->writeQuickMemberLinks(ol,md);
+
+    ol.writeString("   </td>\n");
+    ol.writeString("   <td valign=\"top\">\n");
+    
+    md->writeDocumentation(this,ol,scopeName,container,m_inGroup);
+
+    ol.writeString("    </td>\n");
+    ol.writeString("  </tr>\n");
+    ol.writeString("</table>\n");
+    
+    endFile(ol);
+  }
+  if (memberGroupList)
+  {
+    //printf("MemberList::writeDocumentation()  --  member groups\n");
+    MemberGroupListIterator mgli(*memberGroupList);
+    MemberGroup *mg;
+    for (;(mg=mgli.current());++mgli)
+    {
+      mg->writeDocumentationPage(ol,scopeName,container);
+    }
+  }
 }
 
 void MemberList::addMemberGroup(MemberGroup *mg)
@@ -393,6 +482,7 @@ void MemberList::addMemberGroup(MemberGroup *mg)
   {
     memberGroupList=new MemberGroupList;
   }
+  //printf("addMemberGroup: this=%p mg=%p\n",this,mg);
   memberGroupList->append(mg);
 }
 
@@ -405,9 +495,10 @@ void MemberList::addListReferences(Definition *def)
     if (md->getGroupDef()==0 || def->definitionType()==Definition::TypeGroup)
     {
       md->addListReference(def);
-      if (md->memberType()==MemberDef::Enumeration && md->enumFieldList())
+      LockingPtr<MemberList> enumFields = md->enumFieldList();
+      if (md->memberType()==MemberDef::Enumeration && enumFields!=0)
       {
-        MemberListIterator vmli(*md->enumFieldList());
+        MemberListIterator vmli(*enumFields);
         MemberDef *vmd;
         for ( ; (vmd=vmli.current()) ; ++vmli)
         {
@@ -446,6 +537,69 @@ void MemberList::findSectionsInDocumentation()
   }
 }
 
+void MemberList::marshal(StorageIntf *s)
+{
+  marshalInt(s,(int)m_listType);
+  marshalInt(s,m_varCnt);
+  marshalInt(s,m_funcCnt);
+  marshalInt(s,m_enumCnt);
+  marshalInt(s,m_enumValCnt);
+  marshalInt(s,m_typeCnt);
+  marshalInt(s,m_protoCnt);
+  marshalInt(s,m_defCnt);
+  marshalInt(s,m_friendCnt); 
+  marshalInt(s,m_numDecMembers);
+  marshalInt(s,m_numDocMembers);
+  marshalBool(s,m_inGroup);
+  marshalBool(s,m_inFile);
+  if (memberGroupList==0)
+  {
+    marshalUInt(s,NULL_LIST); // null pointer representation
+  }
+  else
+  {
+    marshalUInt(s,memberGroupList->count());
+    QListIterator<MemberGroup> mgi(*memberGroupList);
+    MemberGroup *mg=0;
+    for (mgi.toFirst();(mg=mgi.current());++mgi)
+    {
+      mg->marshal(s);
+    }
+  }
+}
+
+void MemberList::unmarshal(StorageIntf *s)
+{
+  m_listType       = (MemberList::ListType)unmarshalInt(s);
+  m_varCnt         = unmarshalInt(s);
+  m_funcCnt        = unmarshalInt(s);
+  m_enumCnt        = unmarshalInt(s);
+  m_enumValCnt     = unmarshalInt(s);
+  m_typeCnt        = unmarshalInt(s);
+  m_protoCnt       = unmarshalInt(s);
+  m_defCnt         = unmarshalInt(s);
+  m_friendCnt      = unmarshalInt(s); 
+  m_numDecMembers  = unmarshalInt(s);
+  m_numDocMembers  = unmarshalInt(s);
+  m_inGroup        = unmarshalBool(s);
+  m_inFile         = unmarshalBool(s);
+  uint i,count     = unmarshalUInt(s); 
+  if (count==NULL_LIST) // empty list
+  {
+    memberGroupList = 0;
+  }
+  else // add member groups
+  {
+    memberGroupList = new MemberGroupList;
+    for (i=0;i<count;i++)
+    {
+      MemberGroup *mg = new MemberGroup;
+      mg->unmarshal(s);
+      memberGroupList->append(mg);
+    }
+  }
+}
+
 //--------------------------------------------------------------------------
 
 int MemberSDict::compareItems(GCI item1, GCI item2)
