@@ -3,7 +3,7 @@
  *
  *
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  * Authors: Dimitri van Heesch, Miguel Lobo.
  *
  * Permission to use, copy, modify, and distribute this software and its
@@ -546,7 +546,7 @@ void PerlModDocVisitor::visit(DocSymbol *sy)
   case DocSymbol::Rdquo:   c = '"'; break;
   case DocSymbol::Ndash:   c = '-'; break;
   case DocSymbol::Mdash:   s = "--"; break;
-  case DocSymbol::Nbsp:    c = ''; break;
+  case DocSymbol::Nbsp:    c = ' '; break;
   case DocSymbol::Uml:     accent = "umlaut"; break;
   case DocSymbol::Acute:   accent = "acute"; break;
   case DocSymbol::Grave:   accent = "grave"; break;
@@ -561,6 +561,8 @@ void PerlModDocVisitor::visit(DocSymbol *sy)
   case DocSymbol::Reg:     symbol = "registered"; break;
   case DocSymbol::Szlig:   symbol = "szlig"; break;
   case DocSymbol::Apos:    s = "\\\'"; break;
+  case DocSymbol::Aelig:   symbol = "aelig"; break;
+  case DocSymbol::AElig:   symbol = "AElig"; break;
   case DocSymbol::Unknown:
     err("Error: unknown symbol found\n");
     break;
@@ -1161,6 +1163,7 @@ void PerlModDocVisitor::visitPre(DocParamSect *s)
   case DocParamSect::Param:     type = "params"; break;
   case DocParamSect::RetVal:    type = "retvals"; break;
   case DocParamSect::Exception: type = "exceptions"; break;
+  case DocParamSect::TemplateParam: type = "templateparam"; break;
   case DocParamSect::Unknown:
     err("Error: unknown parameter section found\n");
     break;
@@ -1429,7 +1432,7 @@ void PerlModGenerator::generatePerlModForMember(MemberDef *md,Definition *)
   case MemberDef::Enumeration: memType="enum";      break;
   case MemberDef::Function:    memType="function";  isFunc=TRUE; break;
   case MemberDef::Signal:      memType="signal";    isFunc=TRUE; break;
-  case MemberDef::Prototype:   memType="prototype"; isFunc=TRUE; break;
+  //case MemberDef::Prototype:   memType="prototype"; isFunc=TRUE; break;
   case MemberDef::Friend:      memType="friend";    isFunc=TRUE; break;
   case MemberDef::DCOP:        memType="dcop";      isFunc=TRUE; break;
   case MemberDef::Slot:        memType="slot";      isFunc=TRUE; break;
