@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -68,6 +68,12 @@ class PrintDocVisitor : public DocVisitor
 	case DocSymbol::Copy:    printf("&copy;"); break;
 	case DocSymbol::Apos:    printf("'"); break;
 	case DocSymbol::Quot:    printf("\""); break;
+        case DocSymbol::Lsquo:   printf("&lsquo;"); break;
+        case DocSymbol::Rsquo:   printf("&rsquo;"); break;
+        case DocSymbol::Ldquo:   printf("&ldquo;"); break;
+        case DocSymbol::Rdquo:   printf("&rdquo;"); break;
+        case DocSymbol::Ndash:   printf("&ndash;"); break;
+        case DocSymbol::Mdash:   printf("&mdash;"); break;
 	case DocSymbol::Uml:     printf("&%cuml;",s->letter()); break;
 	case DocSymbol::Acute:   printf("&%cacute;",s->letter()); break;
 	case DocSymbol::Grave:   printf("&%cgrave;",s->letter()); break;
@@ -77,6 +83,8 @@ class PrintDocVisitor : public DocVisitor
 	case DocSymbol::Cedil:   printf("&%ccedul;",s->letter()); break;
 	case DocSymbol::Ring:    printf("&%cring;",s->letter()); break;
 	case DocSymbol::Nbsp:    printf("&nbsp;"); break;
+	case DocSymbol::Aelig:   printf("&aelig;"); break;
+	case DocSymbol::AElig:   printf("&AElig;"); break;
 	default:
 	  printf("Error: unknown symbol found\n");
       }
@@ -145,6 +153,7 @@ class PrintDocVisitor : public DocVisitor
         case DocVerbatim::LatexOnly: printf("<latexonly>"); break;
         case DocVerbatim::XmlOnly: printf("<xmlonly>"); break;
         case DocVerbatim::Dot: printf("<dot>"); break;
+        case DocVerbatim::Msc: printf("<msc>"); break;
       }
       printf("%s",s->text().data());
       switch(s->type())
@@ -156,6 +165,7 @@ class PrintDocVisitor : public DocVisitor
         case DocVerbatim::LatexOnly: printf("</latexonly>"); break;
         case DocVerbatim::XmlOnly: printf("</xmlonly>"); break;
         case DocVerbatim::Dot: printf("</dot>"); break;
+        case DocVerbatim::Msc: printf("</msc>"); break;
       }
     }
     void visit(DocAnchor *a)
@@ -581,6 +591,7 @@ class PrintDocVisitor : public DocVisitor
 	case DocParamSect::Param: printf("param"); break;
 	case DocParamSect::RetVal: printf("retval"); break;
 	case DocParamSect::Exception: printf("exception"); break;
+	case DocParamSect::TemplateParam: printf("templateparam"); break;
 	case DocParamSect::Unknown: printf("unknown"); break;
       }
       printf(">\n");
