@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -21,20 +21,22 @@
 #include "language.h"
 #include "doxygen.h"
 #include "outputgen.h"
-#include "code.h"
 #include "dot.h"
 #include "util.h"
 #include "rtfstyle.h"
 #include "message.h"
 #include <qfileinfo.h> 
+#include "parserintf.h"
+#include "msc.h"
 
 
-#define DBG_RTF(x) m_t << x
-//#define DBG_RTF(x) do {} while(0)
+//#define DBG_RTF(x) m_t << x
+#define DBG_RTF(x) do {} while(0)
 
-RTFDocVisitor::RTFDocVisitor(QTextStream &t,BaseCodeDocInterface &ci) 
+RTFDocVisitor::RTFDocVisitor(QTextStream &t,CodeOutputInterface &ci,
+                             const char *langExt) 
   : DocVisitor(DocVisitor_RTF), m_t(t), m_ci(ci), m_insidePre(FALSE), 
-    m_hide(FALSE), m_indentLevel(0), m_lastIsPara(FALSE)
+    m_hide(FALSE), m_indentLevel(0), m_lastIsPara(FALSE), m_langExt(langExt)
 {
 }
 
@@ -113,6 +115,12 @@ void RTFDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Reg:     m_t << "(R)"; break;
     case DocSymbol::Apos:    m_t << "'"; break;
     case DocSymbol::Quot:    m_t << "\""; break;
+    case DocSymbol::Lsquo:   m_t << "`"; break;
+    case DocSymbol::Rsquo:   m_t << "'"; break;
+    case DocSymbol::Ldquo:   m_t << "\""; break;
+    case DocSymbol::Rdquo:   m_t << "\""; break;
+    case DocSymbol::Ndash:   m_t << "-"; break;
+    case DocSymbol::Mdash:   m_t << "--"; break;
     case DocSymbol::Uml:     switch(s->letter())
                              {
                                case 'A' : m_t << '\304'; break;
@@ -211,6 +219,8 @@ void RTFDocVisitor::visit(DocSymbol *s)
                              break;
     case DocSymbol::Szlig:   m_t << "\337"; break;
     case DocSymbol::Nbsp:    m_t << "\\~ "; break;
+    case DocSymbol::Aelig:   m_t << "\346"; break;
+    case DocSymbol::AElig:   m_t << "\306"; break;
     default:
                              err("Error: unknown symbol found\n");
   }
@@ -251,7 +261,7 @@ void RTFDocVisitor::visit(DocLineBreak *)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visit(DocLineBreak)}\n");
-  m_t << "\\par\n";
+  m_t << "\\par";
   m_lastIsPara=TRUE;
 }
 
@@ -302,7 +312,7 @@ void RTFDocVisitor::visit(DocStyleChange *s)
       else
       {
         m_insidePre=FALSE;
-        m_t << "\\par" << endl; 
+        m_t << "\\par";
         m_t << "}" << endl;
       }
       m_lastIsPara=TRUE;
@@ -322,7 +332,9 @@ void RTFDocVisitor::visit(DocVerbatim *s)
       m_t << "{" << endl;
       m_t << "\\par" << endl;
       m_t << rtf_Style_Reset << getStyle("CodeExample");
-      parseCode(m_ci,s->context(),s->text().latin1(),s->isExample(),s->exampleFile());
+      Doxygen::parserManager->getParser(m_langExt)
+                            ->parseCode(m_ci,s->context(),s->text().latin1(),
+                                        s->isExample(),s->exampleFile());
       //m_t << "\\par" << endl; 
       m_t << "}" << endl;
       break;
@@ -345,9 +357,10 @@ void RTFDocVisitor::visit(DocVerbatim *s)
         static int dotindex = 1;
         QCString fileName(4096);
 
-        fileName.sprintf("%s%d", 
+        fileName.sprintf("%s%d%s", 
             (Config_getString("RTF_OUTPUT")+"/inline_dotgraph_").data(), 
-            dotindex++
+            dotindex++,
+            ".dot"
            );
         QFile file(fileName);
         if (!file.open(IO_WriteOnly))
@@ -359,7 +372,32 @@ void RTFDocVisitor::visit(DocVerbatim *s)
         m_t << "\\par{\\qc "; // center picture
         writeDotFile(fileName);
         m_t << "} ";
-        file.remove();
+        if (Config_getBool("DOT_CLEANUP")) file.remove();
+      }
+      break;
+    case DocVerbatim::Msc: 
+      {
+        static int mscindex = 1;
+        QCString baseName(4096);
+
+        baseName.sprintf("%s%d", 
+            (Config_getString("RTF_OUTPUT")+"/inline_mscgraph_").data(), 
+            mscindex++
+           );
+        QFile file(baseName+".msc");
+        if (!file.open(IO_WriteOnly))
+        {
+          err("Could not open file %s for writing\n",baseName.data());
+        }
+        QCString text = "msc {";
+        text+=s->text();
+        text+="}";
+        file.writeBlock( text, text.length() );
+        file.close();
+        m_t << "\\par{\\qc "; // center picture
+        writeMscFile(baseName);
+        m_t << "} ";
+        if (Config_getBool("DOT_CLEANUP")) file.remove();
       }
       break;
   }
@@ -401,8 +439,12 @@ void RTFDocVisitor::visit(DocInclude *inc)
          m_t << rtf_Style_Reset << getStyle("CodeExample");
          QFileInfo cfi( inc->file() );
          FileDef fd( cfi.dirPath(), cfi.fileName() );
-         parseCode(m_ci,inc->context(),inc->text().latin1(),inc->isExample(),inc->exampleFile(), &fd);
-         m_t << "\\par" << endl; 
+         Doxygen::parserManager->getParser(inc->extension())
+                               ->parseCode(m_ci,inc->context(),
+                                           inc->text().latin1(),
+                                           inc->isExample(),
+                                           inc->exampleFile(), &fd);
+         m_t << "\\par";
          m_t << "}" << endl;
       }
       break;
@@ -410,8 +452,11 @@ void RTFDocVisitor::visit(DocInclude *inc)
       m_t << "{" << endl;
       m_t << "\\par" << endl;
       m_t << rtf_Style_Reset << getStyle("CodeExample");
-      parseCode(m_ci,inc->context(),inc->text().latin1(),inc->isExample(),inc->exampleFile());
-      m_t << "\\par" << endl; 
+      Doxygen::parserManager->getParser(inc->extension())
+                            ->parseCode(m_ci,inc->context(),
+                                        inc->text().latin1(),inc->isExample(),
+                                        inc->exampleFile());
+      m_t << "\\par";
       m_t << "}" << endl;
       break;
     case DocInclude::DontInclude: 
@@ -423,7 +468,7 @@ void RTFDocVisitor::visit(DocInclude *inc)
       m_t << "\\par" << endl;
       m_t << rtf_Style_Reset << getStyle("CodeExample");
       filter(inc->text());
-      m_t << "\\par" << endl; 
+      m_t << "\\par";
       m_t << "}" << endl;
       break;
   }
@@ -449,7 +494,12 @@ void RTFDocVisitor::visit(DocIncOperator *op)
   if (op->type()!=DocIncOperator::Skip) 
   {
     popEnabled();
-    if (!m_hide) parseCode(m_ci,op->context(),op->text().latin1(),op->isExample(),op->exampleFile());
+    if (!m_hide) 
+    {
+      Doxygen::parserManager->getParser(m_langExt)
+                            ->parseCode(m_ci,op->context(),op->text().latin1(),
+                                        op->isExample(),op->exampleFile());
+    }
     pushEnabled();
     m_hide=TRUE;
   }
@@ -458,7 +508,7 @@ void RTFDocVisitor::visit(DocIncOperator *op)
     popEnabled();
     if (!m_hide)
     {
-      m_t << "\\par" << endl; 
+      m_t << "\\par";
       m_t << "}" << endl;
     }
     m_lastIsPara=TRUE;
@@ -505,7 +555,7 @@ void RTFDocVisitor::visitPost(DocAutoList *)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocAutoList)}\n");
-  m_t << "\\par" << endl;
+  m_t << "\\par";
   m_t << "}" << endl;
   m_lastIsPara=TRUE;
 }
@@ -545,8 +595,9 @@ void RTFDocVisitor::visitPost(DocPara *p)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocPara)}\n");
-  if (!p->isLast() &&            // omit <p> for last paragraph
-      !(p->parent() &&           // and for parameter sections
+  if (!m_lastIsPara &&
+      !p->isLast() &&            // omit <p> for last paragraph
+      !(p->parent() &&           // and for parameters & sections
         p->parent()->kind()==DocNode::Kind_ParamSect
        )
      ) 
@@ -621,7 +672,7 @@ void RTFDocVisitor::visitPre(DocSimpleSect *s)
   if (s->type()!=DocSimpleSect::User && s->type()!=DocSimpleSect::Rcs)
   {
     m_t << ":";
-    m_t << "\\par" << endl;
+    m_t << "\\par";
     m_t << "}"; // end bold
     incIndentLevel();
     m_t << rtf_Style_Reset << getStyle("DescContinue");
@@ -648,8 +699,8 @@ void RTFDocVisitor::visitPost(DocTitle *)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocTitle)}\n");
-  m_t << "}"; // end bold
   m_t << "\\par" << endl;
+  m_t << "}"; // end bold
   incIndentLevel();
   m_t << rtf_Style_Reset << getStyle("DescContinue");
   m_lastIsPara=FALSE;
@@ -713,7 +764,7 @@ void RTFDocVisitor::visitPost(DocSection *)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocSection)}\n");
-  m_t << "}" << endl; // end section
+  m_t << "\\par}" << endl; // end section
   m_lastIsPara=TRUE;
 }
 
@@ -731,7 +782,7 @@ void RTFDocVisitor::visitPost(DocHtmlList *)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocHtmlList)}\n");
-  m_t << "\\par" << endl << "}" << endl;
+  m_t << "\\par" << "}" << endl;
   m_lastIsPara=TRUE;
 }
 
@@ -810,7 +861,7 @@ void RTFDocVisitor::visitPost(DocHtmlDescData *)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocHtmlDescData)}\n");
-  m_t << "\\par" << endl;
+  m_t << "\\par";
   m_t << "}" << endl;
   decIndentLevel();
   m_lastIsPara=TRUE;
@@ -846,7 +897,7 @@ void RTFDocVisitor::visitPre(DocHtmlRow *r)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocHtmlRow)}\n");
-  uint i,columnWidth=rtf_pageWidth/r->numCells();
+  uint i,columnWidth=r->numCells()>0 ? rtf_pageWidth/r->numCells() : 10;
   m_t << "\\trowd \\trgaph108\\trleft-108"
          "\\trbrdrt\\brdrs\\brdrw10 "
          "\\trbrdrl\\brdrs\\brdrw10 "
@@ -911,7 +962,7 @@ void RTFDocVisitor::visitPost(DocInternal *)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocInternal)}\n");
-  m_t << "\\par" << endl;
+  m_t << "\\par";
   decIndentLevel();
   m_t << "}"; // end desc
   m_lastIsPara=TRUE;
@@ -977,7 +1028,7 @@ void RTFDocVisitor::visitPost(DocHtmlHeader *)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocHtmlHeader)}\n");
-  m_t << "\\par" << endl;
+  m_t << "\\par";
   m_t << "}" << endl; // end section
   m_lastIsPara=TRUE;
 }
@@ -1083,8 +1134,8 @@ void RTFDocVisitor::visitPost(DocSecRefList *)
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocSecRefList)}\n");
   decIndentLevel();
-  m_t << "\\par" << endl;
-  m_t << "}";
+  m_t << "\\par";
+  m_t << "}" << endl;
   m_lastIsPara=TRUE;
 }
 
@@ -1125,11 +1176,16 @@ void RTFDocVisitor::visitPre(DocParamSect *s)
       m_t << theTranslator->trReturnValues(); break;
     case DocParamSect::Exception: 
       m_t << theTranslator->trExceptions(); break;
+    case DocParamSect::TemplateParam: 
+      /* TODO: add this 
+      m_t << theTranslator->trTemplateParam(); break;
+      */
+      m_t << "Template Parameters"; break;
     default:
       ASSERT(0);
   }
   m_t << ":";
-  m_t << "\\par" << endl;
+  m_t << "\\par";
   m_t << "}" << endl;
   incIndentLevel();
   m_t << rtf_Style_Reset << getStyle("DescContinue");
@@ -1149,14 +1205,43 @@ void RTFDocVisitor::visitPre(DocParamList *pl)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocParamList)}\n");
+
+  // Put in the direction: in/out/in,out if specified.
+  if (pl->direction()!=DocParamSect::Unspecified)
+  {
+    m_t << "[";
+    if (pl->direction()==DocParamSect::In)
+    {
+      m_t << "in";
+    }
+    else if (pl->direction()==DocParamSect::Out)
+    {
+      m_t << "out";
+    }
+    else if (pl->direction()==DocParamSect::InOut)
+    {
+      m_t << "in,out";
+    }
+    m_t << "] ";
+  }
+
   m_t << "{\\i ";
-  QStrListIterator li(pl->parameters());
-  const char *s;
+  //QStrListIterator li(pl->parameters());
+  //const char *s;
+  QListIterator<DocNode> li(pl->parameters());
+  DocNode *param;
   bool first=TRUE;
-  for (li.toFirst();(s=li.current());++li)
+  for (li.toFirst();(param=li.current());++li)
   {
     if (!first) m_t << ","; else first=FALSE;
-    filter(s);
+    if (param->kind()==DocNode::Kind_Word)
+    {
+      visit((DocWord*)param); 
+    }
+    else if (param->kind()==DocNode::Kind_LinkedWord)
+    {
+      visit((DocLinkedWord*)param); 
+    }
   }
   m_t << "} ";
   m_lastIsPara=TRUE;
@@ -1211,7 +1296,7 @@ void RTFDocVisitor::visitPre(DocXRefItem *x)
     filter(x->title());
   }
   m_t << ":";
-  m_t << "\\par" << endl;
+  m_t << "\\par";
   m_t << "}"; // end bold
   incIndentLevel();
   m_t << rtf_Style_Reset << getStyle("DescContinue");
@@ -1263,12 +1348,12 @@ void RTFDocVisitor::visitPost(DocText *)
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocText)}\n");
 }
 
-static char* getMultiByte(int c)
-{
-    static char s[10];
-    sprintf(s,"\\'%X",c);
-    return s;
-}
+//static char* getMultiByte(int c)
+//{
+//    static char s[10];
+//    sprintf(s,"\\'%X",c);
+//    return s;
+//}
 
 void RTFDocVisitor::filter(const char *str,bool verbatim)
 { 
@@ -1279,21 +1364,21 @@ void RTFDocVisitor::filter(const char *str,bool verbatim)
     unsigned char pc='\0';
     while (*p)
     {
-      static bool MultiByte = FALSE;
+      //static bool MultiByte = FALSE;
       c=*p++;
 
-      if ( MultiByte )
-      {
-        m_t << getMultiByte( c );
-        MultiByte = FALSE;
-        continue;
-      }
-      if ( c >= 0x80 )
-      {
-        MultiByte = TRUE;
-        m_t << getMultiByte( c );
-        continue;
-      }
+      //if ( MultiByte )
+      //{
+      //  m_t << getMultiByte( c );
+      //  MultiByte = FALSE;
+      //  continue;
+      //}
+      //if ( c >= 0x80 )
+      //{
+      //  MultiByte = TRUE;
+      //  m_t << getMultiByte( c );
+      //  continue;
+      //}
 
       switch (c)
       {
@@ -1389,4 +1474,23 @@ void RTFDocVisitor::writeDotFile(const QString &fileName)
   m_lastIsPara=TRUE;
 }
 
+void RTFDocVisitor::writeMscFile(const QString &fileName)
+{
+  QString baseName=fileName;
+  int i;
+  if ((i=baseName.findRev('/'))!=-1)
+  {
+    baseName=baseName.right(baseName.length()-i-1);
+  } 
+  QString outDir = Config_getString("RTF_OUTPUT");
+  writeMscGraphFromFile(fileName,outDir,baseName,MSC_BITMAP);
+  if (!m_lastIsPara) m_t << "\\par" << endl;
+  m_t << "{" << endl;
+  m_t << rtf_Style_Reset;
+  m_t << "\\pard \\qc {\\field\\flddirty {\\*\\fldinst INCLUDEPICTURE \"";
+  m_t << baseName << ".png";
+  m_t << "\" \\\\d \\\\*MERGEFORMAT}{\\fldrslt IMAGE}}\\par" << endl;
+  m_t << "}" << endl;
+  m_lastIsPara=TRUE;
+}
 
