@@ -16,20 +16,23 @@
  */
 
 /*
- * translator_jp.h
- *
+ * translator_jp.h 
+ * Updates:
  * 1.2.5)
  * First Translation
  *      by Kenji Nagamatsu
  * 1.2.12)
  * Update and Shift-Jis(_WIN32)
  *      by Ryunosuke Sato (30-Dec-2001)
+ * 1.5.8)
+ * Translation for 1.5.8.
+ *      by Hiroki Iseri (18-Feb-2009)
  */
 
 #ifndef TRANSLATOR_JP_H
 #define TRANSLATOR_JP_H
 
-class TranslatorJapanese : public TranslatorAdapter_1_5_4
+class TranslatorJapanese : public Translator
 {
  private:
   /*! The decode() can change euc into sjis */
@@ -101,17 +104,17 @@ class TranslatorJapanese : public TranslatorAdapter_1_5_4
     virtual QCString trMemberDataDocumentation()
     {
       if( Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
-	{
-	  return decode("¤");
-	}
+	  {
+	    return decode("¤");
+	  }
       else
-	{
-	  return decode("ѿ");
-	}
+	  {
+	    return decode("ѿ");
+	  }
     }
 
     /*! this is the text of a link put after brief descriptions. */
-    virtual QCString trMore()
+	virtual QCString trMore()
     { return decode("[ܺ]"); }
 
     /*! put in the class documentation */
@@ -254,15 +257,15 @@ class TranslatorJapanese : public TranslatorAdapter_1_5_4
     {
       QCString result=decode("");
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
-	{
-	  result+=decode("եɤΰǤ줾");
-	  if (extractAll) result+=decode("°Ƥ빽¤/");
-	}
+	  {
+	    result+=decode("եɤΰǤ줾");
+	    if (extractAll) result+=decode("°Ƥ빽¤/");
+	  }
       else
-	{
-	  result+=decode("饹Фΰǡ줾");
-	  if (extractAll) result+=decode("°Ƥ륯饹");
-	}
+	  {
+	    result+=decode("饹Фΰǡ줾");
+	    if (extractAll) result+=decode("°Ƥ륯饹");
+	  }
       result+=decode("إ󥯤Ƥޤ");
       return result;
     }
@@ -1582,5 +1585,188 @@ class TranslatorJapanese : public TranslatorAdapter_1_5_4
     virtual QCString trEnumerationValueDocumentation()
     { return decode(""); }
 
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.5.4 (mainly for Fortran)
+//////////////////////////////////////////////////////////////////////////
+    
+    /*! header that is put before the list of member subprograms (Fortran). */
+    virtual QCString trMemberFunctionDocumentationFortran()
+    { return decode("ؿ/֥롼"); }
+
+    /*! This is put above each page as a link to the list of annotated data types (Fortran). */    
+    virtual QCString trCompoundListFortran()
+    { return decode("ǡ"); }
+
+    /*! This is put above each page as a link to all members of compounds (Fortran). */
+    virtual QCString trCompoundMembersFortran()
+    { return decode("ǡե"); }
+    
+    /*! This is an introduction to the annotated compound list (Fortran). */
+    virtual QCString trCompoundListDescriptionFortran()
+    { return decode("ϥǡΰǤ"); }
+    
+    /*! This is an introduction to the page with all data types (Fortran). */
+    virtual QCString trCompoundMembersDescriptionFortran(bool extractAll)
+    {
+	  QCString result=decode("");
+	  result+=decode("եɤΰǤ줾");
+	  if (extractAll)
+	  {
+	  	result+=decode("°Ƥǡ");
+	  }
+	  result+=decode("إ󥯤Ƥޤ");
+	  return result;
+    }
+	
+    /*! This is used in LaTeX as the title of the chapter with the 
+     * annotated compound index (Fortran).
+     */
+    virtual QCString trCompoundIndexFortran()
+    { return decode("ǡ"); }
+
+    /*! This is used in LaTeX as the title of the chapter containing
+     *  the documentation of all data types (Fortran).
+     */
+    virtual QCString trTypeDocumentation()
+    { return decode("ǡ"); }
+
+    /*! This is used in the documentation of a file as a header before the 
+     *  list of (global) subprograms (Fortran).
+     */
+    virtual QCString trSubprograms()
+    { return decode("ؿ/֥롼"); }
+
+
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for subprograms (Fortran)
+     */
+    virtual QCString trSubprogramDocumentation()
+    { return decode("ؿ/֥롼"); }
+
+    /*! This is used in the documentation of a file/namespace/group before 
+     *  the list of links to documented compounds (Fortran)
+     */
+     virtual QCString trDataTypes()
+    { return decode("ǡ"); }
+    
+    /*! used as the title of page containing all the index of all modules (Fortran). */
+    virtual QCString trModulesList()
+    { return decode("⥸塼"); }
+
+    /*! used as an introduction to the modules list (Fortran) */
+    virtual QCString trModulesListDescription(bool extractAll)
+    {
+      QCString result=decode("");
+      if (!extractAll) result+=decode("줿");
+      result+=decode("⥸塼Ǥ");
+      return result;
+    }
+
+    /*! used as the title of the HTML page of a module/type (Fortran) */
+    virtual QCString trCompoundReferenceFortran(const char *clName,
+                                    ClassDef::CompoundType compType,
+                                    bool isTemplate)
+    {
+      QCString result="";
+      switch(compType)
+      {
+        case ClassDef::Class:      result+=decode("⥸塼 "); break;
+        case ClassDef::Struct:     result+=decode("TYPE "); break;
+        case ClassDef::Union:      result+=decode(" "); break;
+        case ClassDef::Interface:  result+=decode("󥿡ե "); break;
+        case ClassDef::Protocol:   result+=decode("ץȥ "); break;
+        case ClassDef::Category:   result+=decode("ƥ "); break;
+        case ClassDef::Exception:  result+=decode("㳰 "); break;
+      }
+      if (isTemplate) result += decode("ƥץ졼 ");
+      result+=(QCString)clName;
+      return result;
+    }
+    /*! used as the title of the HTML page of a module (Fortran) */
+    virtual QCString trModuleReference(const char *namespaceName)
+    {
+      QCString result=namespaceName;
+      result+=decode("⥸塼");        
+      return result;
+    }
+    
+    /*! This is put above each page as a link to all members of modules. (Fortran) */
+    virtual QCString trModulesMembers()
+    { return decode("⥸塼"); }
+
+    /*! This is an introduction to the page with all modules members (Fortran) */
+    virtual QCString trModulesMemberDescription(bool extractAll)
+    { 
+      QCString result=decode("ϥ⥸塼аǤ줾 ");
+      if (extractAll) 
+      {
+        result+=decode("°Ƥ⥸塼");
+      }
+	  result+=decode("إ󥯤Ƥޤ");
+      return result;
+    }
+
+    /*! This is used in LaTeX as the title of the chapter with the 
+     *  index of all modules (Fortran).
+     */
+    virtual QCString trModulesIndex()
+    { return decode("⥸塼"); }
+    
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trModule(bool /*first_capital*/, bool /*singular*/)
+    {       
+      return decode("⥸塼");
+    }
+    /*! This is put at the bottom of a module documentation page and is
+     *  followed by a list of files that were used to generate the page.
+     */
+    virtual QCString trGeneratedFromFilesFortran(ClassDef::CompoundType compType,
+        bool /*single*/)
+    { // here s is one of " Module", " Struct" or " Union"
+      // single is true implies a single file
+      QCString result="";
+      switch(compType)
+      {
+        case ClassDef::Class:      result+=decode("⥸塼"); break;
+        case ClassDef::Struct:     result+=decode("TYPE"); break;
+        case ClassDef::Union:      result+=decode(""); break;
+        case ClassDef::Interface:  result+=decode("󥿡ե"); break;
+        case ClassDef::Protocol:   result+=decode("ץȥ"); break;
+        case ClassDef::Category:   result+=decode("ƥ"); break;
+        case ClassDef::Exception:  result+=decode("㳰"); break;
+      }
+      result+=decode(decode("ϼΥե뤫ޤ:"));
+      return result;
+    }
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trType(bool /*first_capital*/, bool /*singular*/)
+    { 
+      QCString result = decode("TYPE");
+      return result; 
+    }
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trSubprogram(bool /*first_capital*/, bool /*singular*/)
+    { 
+      QCString result = decode("֥ץ");
+      return result; 
+    }
+
+    /*! C# Type Constraint list */
+    virtual QCString trTypeConstraints()
+    {
+      return decode("");
+    }
+
 };
+
 #endif
