@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -20,8 +20,8 @@
 
 
 /* Korean translators
- * doxygen-cvs
- *   * fly1004
+ * doxygen-svn
+ *   * fly1004@gmail.com
  * doxygen-1.5.3
  *   * Astromaker(http://ngps.net/)
  *   * gpgiki(http://www.gpgstudy.com/gpgiki/)
@@ -1064,8 +1064,7 @@ class TranslatorKorean : public Translator
         "    Used *m_usedClass;\n"
         "};\n"
         "\\endcode\n"
-        " Ͽ \\c MAX_DOT_GRAPH_HEIGHT ±װ "
-        "240 Ǿٸ,   ׷ µ Դϴ. :"
+        "  ׷ µ Դϴ. :"
         "<p><center><img alt=\"\" src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center>\n"
         "<p>\n"
         " ׷ ڽ   ǹ̸ ϴ. :\n"
@@ -1574,7 +1573,7 @@ class TranslatorKorean : public Translator
      */
     virtual QCString trOverloadText()
     {
-       return " Լ  ϱ  ε  ԼԴϴ. "
+       return " Լ Ǹ ϱ  ε  ԼԴϴ. "
               " Լ Ʋ   ޾Ƶ̴ ƱԸƮ(argument) ٸٴ Դϴ.";
     }
 
@@ -1594,6 +1593,206 @@ class TranslatorKorean : public Translator
     virtual QCString trEnumerationValueDocumentation()
     { return " ȭ"; }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.5.4 (mainly for Fortran)
+//////////////////////////////////////////////////////////////////////////
+    
+    /*! header that is put before the list of member subprograms (Fortran). */
+    virtual QCString trMemberFunctionDocumentationFortran()
+    { return " Լ/ƾ ȭ"; }
+
+    /*! This is put above each page as a link to the list of annotated data types (Fortran). */    
+    virtual QCString trCompoundListFortran()
+    { return "Ÿ Ÿ "; }
+
+    /*! This is put above each page as a link to all members of compounds (Fortran). */
+    virtual QCString trCompoundMembersFortran()
+    { return "Ÿ ʵ"; }
+
+    /*! This is an introduction to the annotated compound list (Fortran). */
+    virtual QCString trCompoundListDescriptionFortran()
+    { return "뷫  Բ Ÿ ŸԵ Դϴ.:"; }
+
+    /*! This is an introduction to the page with all data types (Fortran). */
+    virtual QCString trCompoundMembersDescriptionFortran(bool extractAll)
+    {
+      QCString result=" ";
+      if (!extractAll)
+      {
+        result+="ȭ ";
+      }
+      result+=" Ÿ Ÿ  Դϴ. ";
+
+      result+=" ׸ ";
+      if (!extractAll) 
+      {
+         result+="   Ÿ  ȭ  ũ  ֽϴ.";
+      }
+      else 
+      {
+         result+="׵  Ÿ Ÿ ũ  ֽϴ. :";
+      }
+      return result;
+    }
+
+    /*! This is used in LaTeX as the title of the chapter with the 
+     * annotated compound index (Fortran).
+     */
+    virtual QCString trCompoundIndexFortran()
+    { return "Ÿ Ÿ "; }
+
+    /*! This is used in LaTeX as the title of the chapter containing
+     *  the documentation of all data types (Fortran).
+     */
+    virtual QCString trTypeDocumentation()
+    { return "Ÿ Ÿ ȭ"; }
+
+    /*! This is used in the documentation of a file as a header before the 
+     *  list of (global) subprograms (Fortran).
+     */
+    virtual QCString trSubprograms()
+    { return "Լ/ƾ"; }
+
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for subprograms (Fortran)
+     */
+    virtual QCString trSubprogramDocumentation()
+    { return "Լ/ƾ ȭ"; }
+
+    /*! This is used in the documentation of a file/namespace/group before 
+     *  the list of links to documented compounds (Fortran)
+     */
+     virtual QCString trDataTypes()
+    { return "Ÿ ŸԵ"; }
+    
+    /*! used as the title of page containing all the index of all modules (Fortran). */
+    virtual QCString trModulesList()
+    { return " "; }
+
+    /*! used as an introduction to the modules list (Fortran) */
+    virtual QCString trModulesListDescription(bool extractAll)
+    {
+      QCString result=" ";
+      if (!extractAll) result+="ȭ ";
+      result+=" ⿡  Դϴ. (  ݴϴ) :";
+      return result;
+    }
+
+    /*! used as the title of the HTML page of a module/type (Fortran) */
+    virtual QCString trCompoundReferenceFortran(const char *clName,
+                                    ClassDef::CompoundType compType,
+                                    bool isTemplate)
+    {
+      QCString result=(QCString)clName;
+      switch(compType)
+      {
+        case ClassDef::Class:      result+=" "; break;
+        case ClassDef::Struct:     result+=" Ÿ"; break;
+        case ClassDef::Union:      result+=" ü"; break;
+        case ClassDef::Interface:  result+=" ̽"; break;
+        case ClassDef::Protocol:   result+=" "; break;
+        case ClassDef::Category:   result+=" īװ"; break;
+        case ClassDef::Exception:  result+=" "; break;
+      }
+      if (isTemplate) result+=" ø";
+      result+=" ";
+      return result;
+    }
+    /*! used as the title of the HTML page of a module (Fortran) */
+    virtual QCString trModuleReference(const char *namespaceName)
+    {
+      QCString result=namespaceName;
+      result+="  ";        
+      return result;
+    }
+    
+    /*! This is put above each page as a link to all members of modules. (Fortran) */
+    virtual QCString trModulesMembers()
+    { return " "; }
+
+    /*! This is an introduction to the page with all modules members (Fortran) */
+    virtual QCString trModulesMemberDescription(bool extractAll)
+    { 
+      QCString result=" ";
+      if (!extractAll) result+="ȭ ";
+      result+="   Դϴ. ";
+      if (extractAll) 
+      {
+        result+=" ׸    ȭ  ũ  ֽϴ. :";
+      }
+      else 
+      {
+        result+=" ׸ ׵   ũ  ֽϴ. :";
+      }
+      return result;
+    }
+
+    /*! This is used in LaTeX as the title of the chapter with the 
+     *  index of all modules (Fortran).
+     */
+    virtual QCString trModulesIndex()
+    { return " "; }
+    
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trModule(bool first_capital, bool singular)
+    {       
+      QCString result((first_capital ? "" : ""));
+      if (!singular)  result+="";
+      return result; 
+    }
+    /*! This is put at the bottom of a module documentation page and is
+     *  followed by a list of files that were used to generate the page.
+     */
+    virtual QCString trGeneratedFromFilesFortran(ClassDef::CompoundType compType,
+        bool single)
+    { // here s is one of " Module", " Struct" or " Union"
+      // single is true implies a single file
+      QCString result=(QCString)" ";
+      if (single) result+=""; else result+="";
+      result+="κ  ";
+      result+=" ";
+      switch(compType)
+      {
+        case ClassDef::Class:      result+=""; break;
+        case ClassDef::Struct:     result+="Ÿ"; break;
+        case ClassDef::Union:      result+="ü"; break;
+        case ClassDef::Interface:  result+="̽"; break;
+        case ClassDef::Protocol:   result+=""; break;
+        case ClassDef::Category:   result+="īװ"; break;
+        case ClassDef::Exception:  result+=""; break;
+      }
+      result+=" ȭ :";
+      return result;
+    }
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trType(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "Ÿ" : "Ÿ"));
+      if (!singular)  result+="";
+      return result; 
+    }
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trSubprogram(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "α׷" : "α׷"));
+      if (!singular)  result+="";
+      return result; 
+    }
+
+    /*! C# Type Constraint list */
+    virtual QCString trTypeConstraints()
+    {
+      return "Ÿ ڵ";
+    }
 
 };
 
