@@ -2,7 +2,7 @@
  *
  * $Id: util.h,v 1.49 2001/03/19 19:27:42 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -85,14 +85,17 @@ class TextGeneratorOLImpl : public TextGeneratorIntf
 
 enum SrcLangExt
 {
-  SrcLangExt_IDL    = 0x008,
-  SrcLangExt_Java   = 0x010,
-  SrcLangExt_CSharp = 0x020,
-  SrcLangExt_D      = 0x040,
-  SrcLangExt_PHP    = 0x080,
-  SrcLangExt_ObjC   = 0x100,
-  SrcLangExt_Cpp    = 0x200,
-  SrcLangExt_JS     = 0x400,
+  SrcLangExt_IDL    = 0x0008,
+  SrcLangExt_Java   = 0x0010,
+  SrcLangExt_CSharp = 0x0020,
+  SrcLangExt_D      = 0x0040,
+  SrcLangExt_PHP    = 0x0080,
+  SrcLangExt_ObjC   = 0x0100,
+  SrcLangExt_Cpp    = 0x0200,
+  SrcLangExt_JS     = 0x0400,
+  SrcLangExt_Python = 0x0800,
+  SrcLangExt_F90    = 0x1000,
+  SrcLangExt_VHDL   = 0x2000
 };
 
 //--------------------------------------------------------------------
@@ -132,7 +135,9 @@ bool resolveRef(/* in */  const char *scName,
                 /* in */  const char *name,
                 /* in */  bool inSeeBlock,
                 /* out */ Definition **resContext,
-                /* out */ MemberDef  **resMember
+                /* out */ MemberDef  **resMember,
+                /* in */  bool lookForSpecializations = TRUE,
+                /* in */  FileDef *currentFile = 0
                );
 
 bool resolveLink(/* in */  const char *scName,
@@ -188,7 +193,10 @@ QCString showFileDefMatches(const FileNameDict *fnDict,const char *n);
 
 int guessSection(const char *name);
 
-bool isId(int c);
+inline bool isId(int c)
+{
+  return c=='_' || isalnum(c) || c>=128 || c<0;
+}
 
 QCString removeRedundantWhiteSpace(const QCString &s);
 
@@ -321,15 +329,18 @@ void stringToSearchIndex(const QCString &docUrlBase,const QCString &title,
                          const QCString &str, bool priority=FALSE,
                          const QCString &anchor="");
 
+bool updateLanguageMapping(const QCString &extension,const QCString &parser);
 SrcLangExt getLanguageFromFileName(const QCString fileName);
+void initDefaultExtensionMapping();
 
 bool checkIfTypedef(Definition *scope,FileDef *fileScope,const char *n);
 
 ClassDef *newResolveTypedef(FileDef *fileScope,MemberDef *md,
                             MemberDef **pMemType=0,QCString *pTemplSpec=0,
-                            QCString *pResolvedType=0);
+                            QCString *pResolvedType=0,
+                            ArgumentList *actTemplParams=0);
 
-QCString parseCommentAsText(const QString &doc,const QCString &fileName,int lineNr);
+QCString parseCommentAsText(const Definition *scope,const MemberDef *member,const QString &doc,const QCString &fileName,int lineNr);
 
 QCString transcodeCharacterStringToUTF8(const QCString &input);
 
@@ -346,6 +357,10 @@ QCString expandAlias(const QCString &aliasName,const QCString &aliasValue);
 
 void writeTypeConstraints(OutputList &ol,Definition *d,ArgumentList *al);
 
+QCString convertCharEntitiesToUTF8(const QCString &s);
+
+bool usingTreeIndex();
+void stackTrace();
 
 #endif
 
