@@ -75,7 +75,7 @@ static const char* g_vhdlKeyWordMap0[] =
   "range", "record", "register", "reject", "report", "return","select", 
   "severity", "shared", "signal", "subtype", "then", "to", "transport", 
   "type","unaffected", "units", "until", "use","variable", "wait", "when", 
-  "while", "with","true","false",0
+  "while", "with","true","false","protected",0
 };
 
 // type
@@ -1049,10 +1049,10 @@ void VhdlDocGen::parseFuncProto(const char* text,QList<Argument>& qlist,
     QCString s1(text);
     s1=s1.stripWhiteSpace();
     int i=s1.find("(",0,FALSE);
-    int s=s1.find(" ",0,FALSE);
-    if (i==-1)
+    int s=s1.find(QRegExp("[ \\t]"));
+    if (i==-1 || i<s)
       s1=VhdlDocGen::getIndexWord(s1.data(),1);
-    else
+    else // s<i, s=start of name, i=end of name
       s1=s1.mid(s,(i-s));
 
     name=s1.stripWhiteSpace();
@@ -1209,7 +1209,7 @@ QCString VhdlDocGen::trTypeString(int type)
     case VhdlDocGen::SHAREDVARIABLE: return "Shared Variable"; 
     case VhdlDocGen::GROUP:          return "Group"; 
     case VhdlDocGen::VFILE:          return "File"; 
-    case VhdlDocGen::COMPONENT_INST: return "Component Instantination"; 
+    case VhdlDocGen::COMPONENT_INST: return "Component Instantiation"; 
     case VhdlDocGen::ALIAS:          return "Alias";
     case VhdlDocGen::CONFIG:         return "Configuration";                                     
     default:                         return "";
@@ -1926,6 +1926,34 @@ void VhdlDocGen::writeVHDLDeclaration(MemberDef* mdef,OutputList &ol,
 	VhdlDocGen::writeProcedureProto(ol,alp.pointer(),mdef);
 
       break;
+    case VhdlDocGen::USE:
+      kl=VhdlDocGen::getClass(mdef->name());
+      if (kl && ((VhdlDocGen::VhdlClasses)kl->protection()==VhdlDocGen::ENTITYCLASS)) break;
+      writeLink(mdef,ol);  
+      ol.insertMemberAlign();
+      ol.docify("  ");
+
+      if (kl)
+      {
+        nn=kl->getOutputFileBase();
+        ol.pushGeneratorState();
+        ol.disableAllBut(OutputGenerator::Html);
+        ol.docify(" ");
+        QCString name=theTranslator_vhdlType(VhdlDocGen::PACKAGE,TRUE);
+        ol.startBold();
+        ol.docify(name.data()); 
+        name.resize(0);
+        ol.endBold();
+        name+=" <"+mdef->name()+">";
+        ol.startEmphasis();
+        ol.writeObjectLink(kl->getReference(),kl->getOutputFileBase(),0,name.data());
+        ol.popGeneratorState();
+      }
+      break;
+    case VhdlDocGen::LIBRARY:
+      writeLink(mdef,ol);
+      ol.insertMemberAlign();
+      break;
     case VhdlDocGen::GENERIC:
     case VhdlDocGen::PORT:
       writeLink(mdef,ol);
