@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -98,6 +98,8 @@ void XmlDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Ring:    m_t << "<ring char=\"" << s->letter() << "\"/>"; break;
     case DocSymbol::Slash:   m_t << "<slash char=\"" << s->letter() << "\"/>"; break;
     case DocSymbol::Nbsp:    m_t << "<nonbreakablespace/>"; break;
+    case DocSymbol::Aelig:   m_t << "<aelig/>"; break;
+    case DocSymbol::AElig:   m_t << "<AElig/>"; break;
     default:
                              err("Error: unknown symbol found\n");
   }
@@ -778,6 +780,8 @@ void XmlDocVisitor::visitPre(DocParamSect *s)
       m_t << "retval"; break;
     case DocParamSect::Exception: 
       m_t << "exception"; break;
+    case DocParamSect::TemplateParam: 
+      m_t << "templateparam"; break;
     default:
       ASSERT(0);
   }
