@@ -564,7 +564,7 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
   // enum values are written as part of the enum
   if (md->memberType()==MemberDef::EnumValue) return;
   if (md->isHidden()) return;
-  if (md->name().at(0)=='@') return; // anonymous member
+  //if (md->name().at(0)=='@') return; // anonymous member
 
   // group members are only visible in their group
   //if (def->definitionType()!=Definition::TypeGroup && md->getGroupDef()) return;
@@ -582,7 +582,6 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
     case MemberDef::Enumeration: memType="enum";      break;
     case MemberDef::Function:    memType="function";  isFunc=TRUE; break;
     case MemberDef::Signal:      memType="signal";    isFunc=TRUE; break;
-    case MemberDef::Prototype:   memType="prototype"; isFunc=TRUE; break;
     case MemberDef::Friend:      memType="friend";    isFunc=TRUE; break;
     case MemberDef::DCOP:        memType="dcop";      isFunc=TRUE; break;
     case MemberDef::Slot:        memType="slot";      isFunc=TRUE; break;
@@ -1238,7 +1237,7 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
       {
         t << convertToXML(
               insertTemplateSpecifierInScope(
-              bcd->classDef->displayName(),bcd->templSpecifiers)
+              bcd->classDef->name(),bcd->templSpecifiers)
            );
       }
       else
